# -*- coding: utf-8 -*-
# @Time    : 2020/4/30 11:34
# @Author  : suhong
# @File    : down.py
# @Software: PyCharm


import os
import webbrowser

import toml
import actasc
import cltmt
import hyxb
import bulletin
import chinjmap
import gfzxb
import cjbcn
import jos
import csa
import huaxuexuebao
import ogp
import stxb
import springer
import zgjkjy
# import teepc_cn
# import jos

# import springer
# import cltmt
# import ogp

DstRoot=""

def ReadConfig():

    # 读取配置文件
    global DstRoot
    cfgFile = 'config.toml'

    with open(cfgFile, mode='rb') as f:
        content = f.read()

    if content.startswith(b'\xef\xbb\xbf'):  # 去掉 utf8 bom 头
        content = content[3:]

    dic = toml.loads(content.decode('utf8'))

    # 读取输出路径
    DstRoot = dic['DstRoot'].strip()
    if not os.path.exists(DstRoot):
        os.makedirs(DstRoot)

    print("PDFRoot: %s"%DstRoot)
    print("Read config_down.toml successed!")


def down():
    return 1
def work():
    # 开关控制
    while True:
        # 选择进行操作
        print("---------------程序初始化完成---------------")
        print("1、环境科学学报")
        print("2、海洋学报：英文版（封面目录在中间）")
        print("3、中国科学院院刊（（注意目录在最前，封面在最后）")
        print("4、中国现代应用药学")
        print("5、高分子学报")
        print("6、生物工程学报")
        print("7、软件学报（封面出到几期则下载几期）")
        print("8、计算机系统应用")
        print("9、化学学报")
        print("10、生态学报（封面出到几期则下载几期）")
        # print("11、纳微快报")
        print("11、汉语教学方法与技术")
        print("12、石油地球物理勘探")
        print("13、中国健康教育")
        # print("注意事项：期刊编号为11时（输入years,代表原网站期刊id,下载时，输入刊id,卷,期）--应通用于springer所有期刊")
        print("注意事项：期刊编号为11时（不用输入years,下载时,输入卷,期）")


        while True:
            journalChouse = input("请输入期刊对应编号：")
            if int(journalChouse) not in [i+1 for i in range(14)]:
                print([i+1 for i in range(14)])
                print("-----------请输入正确期刊对应编号-------------")
                continue
            if journalChouse == "1":
                url ="http://www.actasc.cn/hjkxxb/ch/index.aspx"
            if journalChouse == "2":
                url ="http://www.hyxb.org.cn/aosen/ch/index.aspx"
            if journalChouse == "3":
                url ="http://www.bulletin.cas.cn/zgkxyyk/ch/reader/issue_browser.aspx"
            if journalChouse == "4":
                url = "http://www.chinjmap.com/ch/index.aspx"
            if journalChouse == "5":
                url ="http://www.gfzxb.org/"
            if journalChouse == "6":
                url ="http://journals.im.ac.cn/cjbcn/ch/index.aspx"
            if journalChouse == "7":
                url ="http://www.jos.org.cn/jos/ch/reader/issue_browser.aspx"
            if journalChouse == "8":
                url ="http://www.c-s-a.org.cn/csa/ch/index.aspx"
            if journalChouse == "9":
                url ="http://sioc-journal.cn/Jwk_hxxb/CN/0567-7351/home.shtml"
            if journalChouse == "10":
                url ="http://www.ecologica.cn/stxb/ch/reader/issue_list.aspx?"
            # if journalChouse == "11":
            #     url ="https://link.springer.com/journal/volumesAndIssues/40820"
            if journalChouse == "11":
                url = "https://engagedscholarship.csuohio.edu/cltmt/"
            if journalChouse == "12":
                url = "http://journal08.magtechjournal.com/Jwk_ogp/CN/volumn/home.shtml "
            if journalChouse == "13":
                url = "http://www.zgjkjy.org/Magazine/Default.aspx"


            webbrowser.open(url, new=0, autoraise=True)
            # webbrowser.open_new(url)
            # webbrowser.open_new_tab(url)
            if journalChouse != "11":
                year = input("请输入需要采集的年份:")
                # if journalChouse == "1" :
                #     year = input("请输入需要采集的期刊id:")
                # else:
                #     year = input("请输入需要采集的年份:")
                if year != "0":
                    if len(year) != 4 or not year.isdigit():
                        print("-----------请输入正确年份-------------")
                        continue

            # if journalChouse == "11" or journalChouse == "12":
            if journalChouse == "11":
                vol = input("请输入需要采集的卷次:")
                if (journalChouse) == "11":
                    print("如期次有：This is a supplement情况，输入期次时：期次+'_'+suppl 如(1_suppl)")

            if journalChouse == "12":
                print("num 为No. 后的值，如No.1 , num = 1.No.增刊1, num= 增刊1")

            num = input("请输入需要采集的期次:")
            check = input("确认输入无误：y / n：")

            if check =="y":
                break
            elif check =="n":
                continue
            else:
                print("请输入正确指令")


        checknum =False
        switch = ""

        if journalChouse == "1":
            ReadConfig()
            work = actasc.Actasc()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "2":
            ReadConfig()
            work = hyxb.Hyxb()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "3":
            ReadConfig()
            work = bulletin.Bulletin()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "4":
            ReadConfig()
            work = chinjmap.Chinjmap()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "5":
            ReadConfig()
            work =gfzxb.Gfzxb()
            checknum = work.getpdf(year,num, DstRoot)

        elif journalChouse == "6":
            ReadConfig()
            work = cjbcn.Cjbcn()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "7":
            ReadConfig()
            work = jos.Jos()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "8":
            ReadConfig()
            work = csa.Csa()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "9":
            ReadConfig()
            work = huaxuexuebao.jwk_hxxb()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "10":
            ReadConfig()
            work = stxb.stxb()
            checknum = work.getpdf(year, num, DstRoot)

        # elif journalChouse == "11":
        #     ReadConfig()
        #     work = springer.springer()
        #     checknum = work.getpdf(year, vol, num, DstRoot)

        elif journalChouse == "11":
            ReadConfig()
            work = cltmt.cltmt()
            checknum = work.getpdf(vol, num, DstRoot)

        elif journalChouse == "12":
            ReadConfig()
            work = ogp.ogp()
            checknum = work.getpdf(year, num, DstRoot)

        elif journalChouse == "13":
            ReadConfig()
            work = zgjkjy.zgjk()
            checknum = work.down_pdf(year, num, DstRoot)


            # elif journalChouse == "5":
        #     print("5")
        # elif journalChouse == "6":
        #     print("6")
        # elif journalChouse == "7":
        #     print("7")
        # elif journalChouse == "8":
        #     print("8")
        # elif journalChouse == "9":
        #     print("9")4
        # elif journalChouse == "10":
        #     print("10")
        # elif journalChouse == "11":
        #     print("11")
        # elif journalChouse == "12":
        #     print("12")
        # elif journalChouse == "13":
        #     print("13")
        # elif journalChouse == "14":
        #     print("14")
        # elif journalChouse == "15":


        # 下载成功后，判断程序是否需要继续执行
        if not checknum:
            print("下载--失败：，失败原因：")
            # 询问是否需要继续使用
            switch = input("是否继续采集y/n?：")

            if switch=="n":
                # webbrowser
                break
            elif switch =="y":
                continue
            elif switch == "":
                print("未输入指示，程序结束")
                break
            else:
                print("输入指令错误，程序结束")
                break
        elif checknum:

            print("--------------下载完成--------------")
            print("　　　　　　　　　　　")
            # 询问是否需要继续使用
            switch = input("是否继续采集y/n?:")

            if switch == "n":
                break
            elif switch == "y":
                continue
            elif switch=="":
                print("未输入指示，程序结束")
                break
            else:
                print("输入指令错误，程序结束")
                break


if __name__ == "__main__":
    work()

















# db3数据的连接返回一个连接对象
import sys
import traceback

from re_common.baselibrary import MLogger, BaseAbs
from re_common.baselibrary.database.mbuilder import Sqlite3Builder


class Sqlite3Utiles(object):
    def __init__(self, logger=None):
        self.sqllite3 = None
        self.conn = None
        self.cursor = None

        self._logger = logger

    @property
    def logger(self):
        if self._logger is None:
            return MLogger().streamlogger
        return self._logger

    @logger.setter
    def logger(self, value):
        assert isinstance(value, MLogger)
        self._logger = value

    def get_new_cursor(self):
        """
        获取一个新的游标
        :return:
        """
        # 检查db的存在及是否断掉 不知道为什么 不可以加括号 但编辑器会警告
        return self.conn.cursor()

    def Sqlite3DBConnectFromFilePath(self, dbfilepath, encoding="gbk"):
        """
        通过直接文件连接 我使用Hadoop导下来的db3是gbk编码的
        如果为utf-8编码请改为utf-8
        :param sec:  section
        :return:
        """
        sqllite3 = BaseAbs.get_sql_factory().sqlite_factory()
        # 传入的是配置文件和section选项 dbpath为配置文件路径
        sqlite3_moudle = Sqlite3Builder().build_file_path(dbfilepath).get_moudle()
        sqllite3.link(sqlite3_moudle)
        # 设置txt的编码格式  hadoop 上的db3为gbk 默认为utf8
        sqllite3.set_encoding(encoding=encoding)
        # 返回一个连接
        self.sqllite3 = sqllite3
        self.conn = self.sqllite3.db
        return self

    def Sqlite3DBConnectFromConfig(self, cobnfigfilepath, sec, encoding="gbk"):
        """
        通过配置文件连接
        :param sec:  section
        :return:
        """
        sqllite3 = BaseAbs.get_sql_factory().sqlite_factory()
        # 传入的是配置文件和section选项 dbpath为配置文件路径
        sqlite3_moudle = Sqlite3Builder(cobnfigfilepath, sec).build_all().get_moudle()
        sqllite3.link(sqlite3_moudle)
        # 设置txt的编码格式  hadoop 上的db3为gbk 默认为utf8
        sqllite3.set_encoding(encoding=encoding)
        # 返回一个连接
        self.sqllite3 = sqllite3
        self.conn = self.sqllite3.db
        return self

    def ExeSqlliteList(self, sqlList, errExit=True):
        """
        该函数和上面一样执行一个sql列表且不返回结果
        属于插入和更新类函数 但该函数针对db3
        :param sqllitename:
        :param sqlList:
        :return:
        """
        dbMsg = None
        cur = self.get_new_cursor()
        if self.conn:
            count = 0
            for sql in sqlList:
                count += 1
                try:
                    self.logger.info("{} 执行sql数量:{}".format(sql, str(count)))
                    cur.execute(sql)
                except:
                    self.logger.error('*errSql:' + sql)
                    dbMsg = '*InsertError:' + traceback.format_exc()
                    if errExit:
                        self.logger.error(dbMsg)
                        sys.exit()
                if dbMsg:
                    self.logger.error(dbMsg)
                    continue
        self.conn.commit()
        cur.close()

    def ExeSqlliteMany(self, sql, itermany, errExit=True):
        dbMsg = None
        cur = self.get_new_cursor()
        if self.conn:
            try:
                self.logger.info("{}\n{}".format(sql, str(itermany)))
                cur.executemany(sql, itermany)
            except:
                self.logger.error('*errSql:' + sql)
                dbMsg = '*InsertError:' + traceback.format_exc()
                if errExit:
                    self.logger.error(dbMsg)
                    sys.exit()
            if dbMsg:
                self.logger.error(dbMsg)
        self.conn.commit()
        cur.close()

    def ExeSqlliteSql(self, sql):
        """
        该函数和上面一样执行一个sql列表且不返回结果
        属于插入和更新类函数 但该函数针对db3
        :param sqllitename:
        :param sqlList:
        :return:
        """
        dbMsg = None
        cur = self.get_new_cursor()
        if self.conn:
            try:
                self.logger.info(sql)
                cur.execute(sql)
                self.conn.commit()
            except:
                self.logger.error('*errSql:' + sql)
                dbMsg = '*InsertError:' + traceback.format_exc()
            if dbMsg:
                self.logger.error(dbMsg)
                return False
        else:
            return False
        cur.close()
        return True

    def SelectFromSqlliteFetchall(self, sql):
        """
        该函数和上面一样执行一个sql列表且不返回结果
        属于插入和更新类函数 但该函数针对db3
        :param sqllitename:
        :param sqlList:
        :return:
        """
        cur = self.get_new_cursor()
        if self.conn:
            try:
                self.logger.info(sql)
                cur.execute(sql)
                rows = cur.fetchall()
                return rows
            except:
                self.logger.error('*errSql:' + sql)
                dbMsg = '*InsertError:' + traceback.format_exc()
            if dbMsg:
                self.logger.error(dbMsg)
                return False
        else:
            return False
        cur.close()

    def SelectFromSqlliteFetchall_dicts(self, sql):
        """
        该函数和上面一样执行一个sql列表且不返回结果
        属于插入和更新类函数 但该函数针对db3
        :param sqllitename:
        :param sqlList:
        :return:
        """

        def dict_factory(cursor, row):
            d = {}
            for idx, col in enumerate(cursor.description):
                d[col[0]] = row[idx]
            return d

        self.conn.row_factory = dict_factory
        cur = self.get_new_cursor()
        if self.conn:
            try:
                self.logger.info(sql)
                cur.execute(sql)
                rows = cur.fetchall()
                return rows
            except:
                self.logger.error('*errSql:' + sql)
                dbMsg = '*InsertError:' + traceback.format_exc()
            if dbMsg:
                self.logger.error(dbMsg)
                return False
        else:
            return False
        cur.close()

    def SelectFromSqlliteFetchOne(self, sql):
        """
        该函数和上面一样执行一个sql列表且不返回结果
        属于插入和更新类函数 但该函数针对db3
        :param sqllitename:
        :param sqlList:
        :return:
        """
        dbMsg = None
        cur = self.get_new_cursor()
        if self.conn:
            try:
                self.logger.info(sql)
                cur.execute(sql)
                while True:
                    row = cur.fetchone()
                    if row is None:
                        return None
                    else:
                        yield row
            except:
                self.logger.error('*errSql:' + sql)
                dbMsg = '*InsertError:' + traceback.format_exc()
            if dbMsg:
                self.logger.error(dbMsg)
                return False
        else:
            return False
        cur.close()

    def ExeVACUUM(self):
        """
        清理空间
        :return:
        """
        dbMsg = None
        if self.conn:
            try:
                self.conn.execute("VACUUM")
            except:
                dbMsg = '*VACUUMError:' + traceback.format_exc()
            if dbMsg:
                self.logger.error(dbMsg)
                return False
        else:
            return False
        return True

    def sqliteEscape(self, keyWord):
        keyWord = keyWord.replace("'", "''")
        keyWord = keyWord.replace("\\", "\\\\")
        return keyWord

    def close(self):
        self.conn.close()



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from pymysql.cursors import Cursor


# pymysql的moudle
class SqlMoudle(object):
    def __init__(self):
        """
           host
          string, host to connect
          
        user
          string, user to connect as

        passwd
          string, password to use

        db
          string, database to use

        port
          integer, TCP/IP port to connect to

        这是一个标准连接的所有参数
        cursorclass pymysql.cursors.DictCursor 表示返回数据为dicts
        """
        self.host = None
        self.user = None
        self.password = ""
        self.database = None
        self.port = 3306
        self.unix_socket = None
        self.charset = ''
        self.sql_mode = None
        self.read_default_file = None
        self.conv = None
        self.use_unicode = None
        self.client_flag = 0
        self.cursorclass = Cursor
        self.init_command = None
        self.connect_timeout = 10
        self.ssl = None
        self.read_default_group = None
        self.compress = None
        self.named_pipe = None
        self.autocommit = False
        self.db = None
        self.passwd = None
        self.local_infile = False
        self.max_allowed_packet = 16 * 1024 * 1024
        self.defer_connect = False
        self.auth_plugin_map = None
        self.read_timeout = None
        self.write_timeout = None
        self.bind_address = None
        self.binary_prefix = False
        self.program_name = None
        self.server_public_key = None

    # @property
    # def get_serveraddress(self):
    #     return self._serveraddress
    #
    # @get_serveraddress.setter
    # def set_serveraddress(self,serveraddress):
    #     self._serveraddress = serveraddress
    #
    # @get_serveraddress.deleter
    # def del_serveraddress(self):
    #     del self._serveraddress

    def to_dict(self):
        return self.__dict__

    def __str__(self):
        return str(self.__dict__)


# sqlite3的 moudle
class Sqlite3Moudle(object):
    def __init__(self):
        self.database = ""
        self.timeout = None
        self.detect_types = None
        self.isolation_level = None
        self.check_same_thread = None
        self.factory = None
        self.cached_statements = None
        # self.uri = None

    def to_dict(self):
        return self.__dict__



# -*- coding: utf-8 -*-
# @Time    : 2020/7/16 14:18
# @Author  : suhong
# @File    : zgjkjy.py
# @Software: PyCharm
import json


import requests
from parsel import Selector
import re
import parent

Parent = parent.Parent()


class zgjk(object):
    def __init__(self):
        self.url = "http://www.zgjkjy.org/Magazine/Default.aspx"
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.all_num = 0
        self.title_c = 1
        self.journal = '中国健康教育'
        self.sn = requests.Session()
        self.__VIEWSTATE = None
        self.__EVENTVALIDATION = None
        self.__VIEWSTATEGENERATOR = None
        self.headers = {
            #"Content-Type":"application/x-www-form-urlencoded",
            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            "Host": "www.zgjkjy.org",
            "Origin": "http://www.zgjkjy.org",
            "Cookie":"SiteID=zgjkjy",
            'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.142 Safari/537.36'
        }

    def get_session(self):
        url = "http://www.zgjkjy.org/UserServer/Login.aspx?SiteID=zgjkjy"
        data = {
            '__VIEWSTATE': '/wEPDwULLTExNzE2MjM2NTVkGAEFHl9fQ29udHJvbHNSZXF1aXJlUG9zdEJhY2tLZXlfXxYCBQtja2JSZW1lbWJlcgUIYnRuTG9naW76RrmYZYfx1chBwTJknlUtOWAwdg==',
            '__VIEWSTATEGENERATOR': '0FFF2A42',
            '__EVENTTARGET': '',
            '__EVENTARGUMENT': '',
            '__EVENTVALIDATION': '/wEWBQLr1fizDgKl1bKzCQK1qbSRCwLkx4D4DAKC3IeGDHwfxY+PaZLbnyRo23CckJAFUl6k',
            'txtUserName': 'xmyim26@163.com',
            'txtPassword': '728708',
            'btnLogin.x': 65,
            'btnLogin.y': 20,
        }
        try:
            r = self.sn.post(url=url, data=data,headers=self.headers,allow_redirects=False)
            if r.status_code != 302:
                print(r.status_code)
                return 0
            # cookies = r.cookies

        except Exception as e:
            print(e)
            print("登陆失败")

    def get_canshu(self):
        try:
            r = self.sn.get(self.url)
            r.encoding = r.apparent_encoding
            html = Selector(r.text)
            self.__VIEWSTATE = html.xpath("//input[@id = '__VIEWSTATE']/@value").extract_first()
            self.__VIEWSTATEGENERATOR = html.xpath("//input[@id = '__VIEWSTATEGENERATOR']/@value").extract_first()
            self.__EVENTVALIDATION = html.xpath("//input[@id = '__EVENTVALIDATION']/@value").extract_first()
            print("初始化参数成功")
        except Exception as e:
            print(e)




    def down_pdf(self, years, num, pdfRoot):
        years = str(years)
        num = str(num)
        self.get_session()
        self.get_canshu()
        self.get_all_num(years,num)
        # 第一页访问
        data = {
            '__VIEWSTATE': self.__VIEWSTATE,
            '__VIEWSTATEGENERATOR': self.__VIEWSTATEGENERATOR,
            '__EVENTTARGET': 'pageControl',
            '__EVENTARGUMENT': '1',
            '__EVENTVALIDATION': self.__EVENTVALIDATION,

            'ddlYear': years,
            'ddlMagazine': num,
            'ddlMenu': '',
            'ddlType': 'Keywords',
            'txtKey': '',
            'btnSearch': '查询',

        }
        r = self.sn.post(self.url, data=data,headers=self.headers)
        r.encoding = r.apparent_encoding
        self.savepdf(years,num,pdfRoot,r.text)
        del data['btnSearch']
        page = 1
        while True:
            page +=1
            html = Selector(r.text)
            if r.text.find("PageClass") > 1:
                __VIEWSTATE = html.xpath("//input[@id = '__VIEWSTATE']/@value").extract_first()
                __VIEWSTATEGENERATOR = html.xpath("//input[@id = '__VIEWSTATEGENERATOR']/@value").extract_first()
                __EVENTVALIDATION = html.xpath("//input[@id = '__EVENTVALIDATION']/@value").extract_first()
                data['__VIEWSTATE'] = __VIEWSTATE
                data['__VIEWSTATEGENERATOR'] = __VIEWSTATEGENERATOR
                data['__EVENTVALIDATION'] = __EVENTVALIDATION
                data['__EVENTARGUMENT'] = page
            r = self.sn.post(self.url, data=data, headers=self.headers)
            r.encoding = r.apparent_encoding
            self.savepdf(years, num, pdfRoot, r.text)
            if r.text.find("PageClass") < 0:
                return True
                break

    def get_all_num(self, years, num):
        self.get_session()
        self.get_canshu()
        # 第一页访问
        data = {
            '__VIEWSTATE': self.__VIEWSTATE,
            '__VIEWSTATEGENERATOR': self.__VIEWSTATEGENERATOR,
            '__EVENTTARGET': 'pageControl',
            '__EVENTARGUMENT': '1',
            '__EVENTVALIDATION': self.__EVENTVALIDATION,

            'ddlYear': years,
            'ddlMagazine': num,
            'ddlMenu': '',
            'ddlType': 'Keywords',
            'txtKey': '',
            'btnSearch': '查询',

        }
        r = self.sn.post(self.url, data=data, headers=self.headers)
        r.encoding = r.apparent_encoding
        del data['btnSearch']
        page = 0
        while True:
            page += 1
            html = Selector(r.text)
            if r.text.find("PageClass") > 1:
                __VIEWSTATE = html.xpath("//input[@id = '__VIEWSTATE']/@value").extract_first()
                __VIEWSTATEGENERATOR = html.xpath("//input[@id = '__VIEWSTATEGENERATOR']/@value").extract_first()
                __EVENTVALIDATION = html.xpath("//input[@id = '__EVENTVALIDATION']/@value").extract_first()
                data['__VIEWSTATE'] = __VIEWSTATE
                data['__VIEWSTATEGENERATOR'] = __VIEWSTATEGENERATOR
                data['__EVENTVALIDATION'] = __EVENTVALIDATION
                data['__EVENTARGUMENT'] = page
            r = self.sn.post(self.url, data=data, headers=self.headers)
            r.encoding = r.apparent_encoding
            html = Selector(r.text)
            tr_list = html.xpath("//tr[@class='MagazineTitle']")
            self.all_num += len(tr_list)
            if r.text.find("PageClass") < 0:
                break

    def savepdf(self,years,num,pdfRoot,html):
        html = Selector(html)
        tr_list = html.xpath("//tr[@class='MagazineTitle']")
        for tr in tr_list:
            link = tr.xpath(".//a/@href").extract_first()
            info = tr.xpath("./td[@class='PageClass']/text()").extract_first()
            info = info.strip().replace("\r","")
            pattern = '\):(.*)'
            xx = re.findall(pattern,info)
            url = "http://www.zgjkjy.org"+link.replace("Show.aspx","PDFShow.aspx")
            title = xx[0]
            print("pdf下载链接：%s" % url)
            pdfFilePath = Parent.makedir(self.journal, str(years), str(num), title, pdfRoot)
            print('--------开始下载---------: %s' % title)

            if pdfFilePath == 1:
                self.suc += 1
                continue
            fig = Parent.getPdfbysn(self.sn,url, title, pdfFilePath, self.headers)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                    self.journal, years, num, title.strip())
                line = line + '\n'
                Parent.Record(line, self.journal)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1
                line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                    self.journal, years, num, self.all_num, self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line, self.journal)





# if __name__ == '__main__':
#
#     z = zgjk()
#     # z.down_pdf()
#     z.down_pdf(2020,5,'1')



# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 10:12
# @Author  : suhong
# @File    : cjbcn.py
# @Software: PyCharm

# 1.计算机系统应用
import os
import sys

import re
import requests
from bs4 import BeautifulSoup
from parsel import Selector
import  parent

hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer": "http://journals.im.ac.cn/cjbcn/ch/reader/issue_list.aspx",
        }

Parent = parent.Parent()

class Csa(object):

    def __init__(self):
        self.journal = '计算机系统应用'
        self.base_url = "http://www.c-s-a.org.cn/csa/ch/reader/"
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.all_num = 0

    def getpdf(self, years, num, pdfRoot):
        years = str(years)
        num = str(num)
        url  = "http://www.c-s-a.org.cn/csa/ch/reader/issue_list.aspx?year_id={}&quarter_id={}".format(years,num)
        print(url)
        try:
            r = requests.get(url, headers=hdrs, timeout=60)
        except:

            print('---------------访问失败--------------')
            return False
        line = 'No.' + str(num)
        print(line)
        # 封面下载
        feng = "http://www.c-s-a.org.cn/csa/ch/first_menu.aspx?parent_id=20180126024300505"
        feng_r = requests.get(feng)
        feng_html = Selector(feng_r.text)
        if int(num) < 10:
            t_num = "0" + num
        a_list = feng_html.xpath("//a[contains(@href,'{}')]/@href".format(years+t_num)).extract_first("")
        feng_url = "http://www.c-s-a.org.cn" + a_list
        print(feng_url)
        title = "{}-{}封面".format(years,num)
        pdfFilePath = Parent.makedir(self.journal, years, str(num), title, pdfRoot)
        fig = Parent.getPdf(feng_url, title, pdfFilePath, hdrs)
        if fig == 1:
            print('%s,pdf下载成功' % title)

        html = Selector(r.text)
        li_list  = html.xpath("//li[@class='zynf']")
        self.all_num = len(li_list)
        for li in li_list:
            info = li.xpath("./text()").extract()[0]
            a = li.xpath(".//a[contains(@href,'create_pdf')]/@href").extract()[0]
            info_pa = '\):(.*?) \['
            title = re.findall(info_pa, info)[0]

            pdfurl = self.base_url + a
            print('-----------开始下载-------------: %s' % title)
            pdfFilePath = Parent.makedir(self.journal, years, str(num), title, pdfRoot)
            if pdfFilePath == 1:
                self.suc += 1
                continue
            fig = Parent.getPdf(pdfurl, title, pdfFilePath, hdrs)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                    self.journal, years, num, title.strip())
                line = line + '\n'
                Parent.Record(line, self.journal)
                # print(line)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1
                line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                    self.journal, years, num, self.all_num, self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line, self.journal)
        Parent.Record("\n", self.journal)
        return True

# if __name__ == '__main__':
#     c = Csa()
#     c.getpdf("2020",'5','./')


# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 10:12
# @Author  : suhong
# @File    : gfzxb.py
# @Software: PyCharm

# 1.高分子学报

import sys

import re
import requests
from bs4 import BeautifulSoup
from parsel import Selector
import  parent

hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        }

Parent = parent.Parent()

class Gfzxb(object):

    def __init__(self):
        self.url = 'http://www.gfzxb.org/'
        self.journal = '高分子学报'
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.all_num = 0

    def getpdf(self, years, num, pdfRoot):
        years = str(years)
        num = str(num)
        url  = "http://www.gfzxb.org/article/{}/{}".format(years,num)
        print(url)
        try:
            r = requests.get(url, headers=hdrs, timeout=60)
        except:

            print('---------------访问失败--------------')
            return False
        line = 'No.' + str(num)
        print(line)
        soup = BeautifulSoup(r.text,'lxml')
        all_div = soup.find_all('div',class_='article-list')
        self.all_num = len(all_div)
        xx_num = 0
        for div in all_div:

            id_ = div.get('id')

            info = div.find('div',class_='article-list-time').find("font").get_text()
            info_pa = '\): (.*?)\.'
            title = re.findall(info_pa, info)
            if len(title) == 0:
                title = str(xx_num)
                xx_num +=1
            else:
                title = title[0]
            zy = div.find('div', class_='article-list-zy').find("font",class_='font3').find("a").get_text()
            if "[PDF 0KB]" in zy:
                self.suc +=1
                print('%s,pdf大小为0KB,跳过下载' % title)
                continue
            data = {
                'id':id_
            }
            pdfurl = 'http://www.gfzxb.org/article/exportPdf'
            print('-----------开始下载-------------: %s' % title)
            pdfFilePath = Parent.makedir(self.journal, years, str(num), title, pdfRoot)
            if pdfFilePath == 1:
                self.suc += 1
                continue
            fig = Parent.post_getpdf(data,pdfurl, title, pdfFilePath, hdrs)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (self.journal, years, num, title.strip())
                line = line + '\n'
                Parent.Record(line, self.journal)
                # print(line)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1
                line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                    self.journal, years, num, self.all_num, self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line, self.journal)
        Parent.Record("\n", self.journal)
        return True

# if __name__ == '__main__':
#     a = Gfzxb()
#     a.getpdf("2020",'9','./')



from .utils.mylogger import MLogger

from .readconfig.ini_config import IniConfig

from .database.mbuilder import MysqlBuilderAbstract

from .baseabs import BaseAbs

__all__ = ["BaseAbs", "MysqlBuilderAbstract", "IniConfig", "MLogger"]



# -*- coding: utf-8 -*-
# @Time    : 2020/6/10 10:08
# @Author  : suhong
# @File    : wangfang_pdf_down.py
# @Software: PyCharm

# # 同项目调用基础包
# import os
# import sys
#
# filepath = os.path.abspath(__file__)
# pathlist = filepath.split(os.sep)
# pathlist = pathlist[:-5]
# TopPath = os.sep.join(pathlist)
# sys.path.insert(0, TopPath)
# print(TopPath)

import json
import os
from parsel import Selector
from urllib import parse
import requests
import time

import toml
from re_common.baselibrary.utils.basedir import BaseDir




from bs4 import BeautifulSoup


class Down(object):
    def __init__(self):
        self.sn = None
        self.index_url = "http://www.wanfangdata.com.cn/sns/third-web/per/perio/articleList"
        self.perioname = None
        self.publishYear = None
        self.issueNum = None
        self.proxies = None
        self.perioId = None
        self.pdf_path = None
        self.UserAgent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:60.0) Gecko/20100101 Firefox/60.0'


    def read_toml(self):
        cfgFile = r"./config.toml"
        with open(cfgFile, mode='rb') as f:
            content = f.read()
        if content.startswith(b'\xef\xbb\xbf'):  # 去掉 utf8 bom 头
            content = content[3:]
        config = toml.loads(content.decode('utf8'))
        self.pdf_path = config['pdf_path']
        BaseDir.create_dir(self.pdf_path)
        proxy = config['proxy']
        self.proxies = {
            "http": proxy,
            "https": proxy,
        }
        for info in config['info']['NameList']:
            self.perioname, self.publishYear, self.issueNum = info[0], info[1], info[2]
            print("开始下载{}-{}年-{}期".format(self.perioname, self.publishYear, self.issueNum))
            self.get_id()


    def get_perioid(self):
        url = "http://www.wanfangdata.com.cn/search/searchList.do?searchType=perioInfo&showType=detail&pageSize=20&searchWord={}&isTriggerTag=".format(
            parse.quote(self.perioname))
        r = requests.get(url)
        html = Selector(r.text)
        id_ = html.xpath("//div[@class='title title_h']//a[@class='perInfo_block_title']/@href").extract_first("")
        self.perioId = id_.replace("/perio/detail.do?perio_id=", "")

    def get_id(self):
        self.get_perioid()
        self.Tmp_pdf = r'{}/{}/{}/{}'.format(self.pdf_path,self.perioname, self.publishYear, self.issueNum)
        if not os.path.exists(self.Tmp_pdf):
            os.makedirs(self.Tmp_pdf)
        header = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.142 Safari/537.36',
            "Content-Type" : "application/x-www-form-urlencoded; charset=UTF-8"
        }
        xxx = {
            "page": 1,
            "pageSize": 60,
            "perioId": self.perioId,
            "title": "",
            "publishYear": self.publishYear,
            "issueNum": self.issueNum,
            "otherYear": ""
        }
        r = requests.post(self.index_url, data=xxx)
        print(r.text)
        json_data = json.loads(r.text)
        all_num = json_data['totalRow']
        print("pdf数量：{}".format(all_num))
        max_page = int(all_num // 60) + 1
        for page in range(1, max_page + 1):
            data = {
                "page": page,
                "pageSize": 60,
                "perioId": self.perioId,
                "title": "",
                "publishYear": self.publishYear,
                "issueNum": self.issueNum,
                "otherYear": ""
            }
            r = requests.post(self.index_url, data=data)
            json_data = json.loads(r.text)
            for info in json_data['pageRow']:
                self.sn = requests.Session()
                self.sn.headers['User-Agent'] = self.UserAgent
                rtn = self.down_one(info)
                if rtn[0] != 1:
                    print("下载失败")
                    continue
                    # return -1 * rtn[0]
                r = rtn[1][0]
                title = rtn[1][1]
                title = BaseDir.replace_dir_special_string(title)
                pdf_path = r"{}/{}.pdf".format(self.Tmp_pdf, title)
                if os.path.exists(pdf_path):
                    print("{}存在".format(pdf_path))
                    continue

                self.sava_pdf(r, title)
                time.sleep(2)

    def sava_pdf(self, res, title):
        pdf_path = r"{}/{}.pdf".format(self.Tmp_pdf, title)
        try:
            with open(pdf_path, mode='wb') as f:
                f.write(res.content)
                print("缓存PDF至本地成功:{}".format(title))
            return 1
        except:
            print("缓存PDF至本地失败:{}".format(title))
            return 0

    def down_one(self, info):
        rawid = info['article_id']
        title = info['title']
        doctype = "perio"

        pdfUrl = r"http://oss.wanfangdata.com.cn/file/download/perio_{}.aspx".format(rawid)
        self.sn.headers['Referer'] = r'http://www.wanfangdata.com.cn/pay/downloadliterature.do?_type=%s&id=%s' % (
        doctype, rawid)
        try:
            r = self.sn.get(url=pdfUrl, proxies=self.proxies, timeout=30)
        except Exception as e:
            print(e)
            return 0,0
        html = r.content.decode('utf-8')
        soup = BeautifulSoup(html, 'html.parser')
        aTag = soup.find('iframe', id='downloadIframe')

        if not aTag:
            print('{}所查找的文献详情页无下载链接'.format(rawid))
            return -2, 0
        pdfUrl = aTag.get("src")
        pdfUrl = r"http://oss.wanfangdata.com.cn" + pdfUrl
        try:
            r = self.sn.get(url=pdfUrl, proxies=self.proxies, timeout=30)
        except Exception as e:
            print(e)
            return 0,0
        if r.status_code != 200:
            return 0,0
        return 1, (r, title)


if __name__ == '__main__':

    d = Down()
    d.read_toml()



"""
baserequest
"""
import traceback

import requests

from urllib3.exceptions import InsecureRequestWarning

from re_common.baselibrary.utils.baseurl import BaseUrl
from re_common.baselibrary.utils.core.mlamada import closeResult
from re_common.baselibrary.utils.core.requests_core import USER_AGENT, set_proxy

ok = requests.codes.ok


class BaseRequest(object):
    def __init__(self, logger=None):
        if logger is None:
            from re_common.baselibrary import MLogger
            logger = MLogger().streamlogger
        self.logger = logger

        self.sn = requests.Session()
        self.proxies = None
        # 是否使用类的代理覆盖传入的代理
        self._is_use_proxy = False

    def set_sn(self):
        sn = requests.Session()
        self.sn = sn
        return sn

    def set_proxy(self, proxy):
        """
        配置代理
        :param proxy:
        :return:
        """
        proxies = set_proxy(proxy)
        self.proxies = proxies
        return proxies

    def is_use_proxy(self, boolvalues):
        """
        设置是否使用全局代理
        :param boolvalues:
        :return:
        """
        self._is_use_proxy = boolvalues

    def set_sn_header(self, useragent=None):
        if USER_AGENT != None:
            self.sn.headers['User-Agent'] = useragent
        else:
            self.sn.headers['User-Agent'] = USER_AGENT

    def base_request(self, url, sn=None, endstring="", marks=None, **kwargs):
        """
        网络请求的基本结构
        :param marks:
        :param url:  请求的url
        :param sn:  会话  sn = requests.Session() 这样保存会话
        :param endstring:  判断html的结束字符串 一般html默认 </html> 结尾
        :param mark:  标志符 默认为""  你的结果中的一些字符串或特殊的标签都可以
        :param kwargs: requests请求的一些参数
        :return: true表示成功 false表示失败或需要进行检查的数据，同时返回r
        BoolResult, errString, r
        """
        if marks is None:
            marks = []
        r = None
        exMsg = None
        try:
            requests.urllib3.disable_warnings(InsecureRequestWarning)
            self.logger.info(url)
            # 对https 自动加上verify参数为False
            if BaseUrl.urlScheme(url) == "https":
                kwargs["verify"] = False
            if self._is_use_proxy:
                kwargs["proxies"] = self.proxies
            if sn:
                self.logger.info("requests kwargs is:" + repr(kwargs))
                r = sn.get(url=url, **kwargs)
            else:
                r = requests.get(url=url, **kwargs)
        except:
            exMsg = '* ' + traceback.format_exc()
            self.logger.error(exMsg)
        finally:
            closeResult(r)
        if exMsg:
            self.logger.info("判断到except，请求出项错误")
            return False, "request", r

        if r.status_code != 200:
            self.logger.warning('r.status_code:' + str(r.status_code))
            return False, "code", r

        r.encoding = r.apparent_encoding
        if endstring:
            """
            请求有可能是html或者json等，如果有需要判断html结束的才启动这个选项
            """

            html = r.text.strip()
            if not html.endswith(endstring):
                self.logger.info("not endswith {}".format(endstring))
                return False, "endString", r

        if marks:
            """
           验证请求是否成功  通过一个特征字符串或者html的标签来查找 保证下载的页面是我需要的页面
           而不是错误页面
           特征值有可能没有是网页出现问题  有可能是请求不完全 这个依照情况而定
            """

            html = r.text.strip()
            for mark in marks:
                if html.find(mark) == -1:
                    self.logger.info('not found {}'.format(mark))
                    return False, "Feature err", r
                else:
                    self.logger.info("found mark is {}".format(mark))

        return True, "", r

    def base_request_post(self, url, sn=None, data=None, endstring="", marks=[], **kwargs):
        """
        网络请求的基本结构
        :param url:  请求的url
        :param sn:  会话  sn = requests.Session() 这样保存会话
        :param endstring:  判断html的结束字符串 一般html默认 </html> 结尾
        :param mark:  标志符 默认为""  你的结果中的一些字符串或特殊的标签都可以
        :param kwargs: requests请求的一些参数
        :return: true表示成功 false表示失败或需要进行检查的数据，同时返回r
        """
        r = None
        exMsg = None
        try:
            requests.urllib3.disable_warnings(InsecureRequestWarning)
            self.logger.info(url)
            # 对https 自动加上verify参数为False
            if BaseUrl.urlScheme(url) == "https":
                kwargs["verify"] = False
            if self._is_use_proxy:
                kwargs["proxies"] = self.proxies
            if sn:
                r = sn.post(url=url, data=data, **kwargs)
            else:
                r = requests.post(url=url, data=data, **kwargs)
        except:
            exMsg = '* ' + traceback.format_exc()
            self.logger.error(exMsg)
        finally:
            closeResult(r)

        if exMsg:
            return False, "request", r

        if r.status_code != 200:
            self.logger.warning('r.status_code:' + str(r.status_code))
            return False, "code", r

        r.encoding = r.apparent_encoding

        if endstring:
            """
            请求有可能是html或者json等，如果有需要判断html结束的才启动这个选项
            """
            html = r.text.strip()
            if not html.endswith(endstring):
                self.logger.info("not endswith {}".format(endstring))
                return False, "endString", r

        if marks:
            """
           验证请求是否成功  通过一个特征字符串或者html的标签来查找 保证下载的页面是我需要的页面
           而不是错误页面
           特征值有可能没有是网页出现问题  有可能是请求不完全 这个依照情况而定
            """
            html = r.text.strip()
            for mark in marks:
                if html.find(mark) == -1:
                    self.logger.info('not found {}'.format(mark))
                    return False, "Feature err", r
                else:
                    self.logger.info("found mark is {}".format(mark))

        return True, "", r



from re_common.baselibrary.utils.basefile import BaseFile

from re_common.facade.mysqlfacade import MysqlUtiles


def get_rawid_from_mysql():
    strings = """
            host = 192.168.31.209
            user = root
            passwd = vipdatacenter
            db = cnki_qk
            port = 3306
            chartset = utf8
            """
    mysqlrawid = r"F:\fun2\mysqlrawid.txt"
    feilds = "filename"

    dicts_change = {"key为原来的": "values为现在的"}

    from re_common.baselibrary.tools.stringtodicts import StringToDicts

    dicts = StringToDicts().string_to_dicts_by_equal(strings)
    mysqlutils = MysqlUtiles("", "", builder="MysqlBuilderForDicts", dicts=dicts)
    offset = 0
    limit = 1000000
    while True:
        bools, raws = mysqlutils.SelectFromDB("select `{}` from article limit {},{}".format(feilds, offset, limit))
        if len(raws) == 0:
            break
        with open(mysqlrawid, 'w', encoding="utf-8") as f:
            for row in raws:
                f.write(row[0] + "\n")
        offset = offset + limit


# get_rawid_from_mysql()
# print(BaseFile.get_file_line_num(r'C:\Users\xuzhu\Downloads\part-r-00000'))

def read_files_compose():
    """
    读取两个文件对比
    :return:
    """
    sets1 = set()
    sets2 = set()
    for value in BaseFile.read_file_r_mode_yield(r'C:\Users\xuzhu\Downloads\part-r-00000'):
        sets2.add(value)

    for value in BaseFile.read_file_r_mode_yield(r'F:\fun2\mysqlrawid.txt'):
        sets1.add(value)
    set3 = sets1 - sets2
    cha = r"F:\fun2\cha.txt"
    with open(cha, 'w', encoding="utf-8") as f:
        for row in set3:
            f.write(row + "\n")


#read_files_compose()

def set_stat():
    strings = """
               host = 192.168.31.209
               user = root
               passwd = vipdatacenter
               db = cnki_qk
               port = 3306
               chartset = utf8
               """
    charawid = r"F:\fun2\cha.txt"

    dicts_change = {"key为原来的": "values为现在的"}

    from re_common.baselibrary.tools.stringtodicts import StringToDicts

    dicts = StringToDicts().string_to_dicts_by_equal(strings)
    mysqlutils = MysqlUtiles("", "", builder="MysqlBuilderForDicts", dicts=dicts)
    lists = []
    for values in BaseFile.read_file_r_mode_yield(charawid):
        lists.append(values)
        if len(lists) > 100000:
            sql = "update article set stat=0,ref_stat=0 where filename in {}".format(tuple(lists))
            mysqlutils.ExeSqlToDB(sql)
            lists.clear()

    if len(lists) > 0:
        if len(lists) == 1:
            lists.append("test")
        sql = "update article set stat=0,ref_stat=0 where filename in {}".format(tuple(lists))
        mysqlutils.ExeSqlToDB(sql)
        lists.clear()

set_stat()


# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 11:49
# @Author  : suhong
# @File    : huaxuexuebao.py
# @Software: PyCharm

"""化学学报"""

import requests
from bs4 import BeautifulSoup
from lxml import etree
import  parent

# -*- coding: utf-8 -*-
# @Time    : 2019/6/27 15:11
# @Author  : qianjun
# @FileName: huaxuexuebao.py
# @Software: PyCharm

"""化学学报"""
import sys

import requests
from bs4 import BeautifulSoup
from lxml import etree
import  parent

hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer": "http://sioc-journal.cn",
        }

Parent = parent.Parent()

class jwk_hxxb(object):

    def __init__(self):
        self.url = 'http://sioc-journal.cn/Jwk_hxxb/CN/volumn/current.shtml'
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.journal = '化学学报'

    def getpdf(self,years, num,pdfRoot):
        years = str(years)
        num = str(num)
        url = 'http://sioc-journal.cn/Jwk_hxxb/CN/article/showTenYearVolumnDetail.do?nian=%s' % years
        print(url)
        try:
            r = requests.get(url, hdrs, timeout = 60)
        except:

            print('---------------访问失败--------------')
            return False
        line = 'No.' + str(num)
        print(line)
        # 创建xpath对象
        html = etree.HTML(r.content.decode())


        # # 获取所有的标签对象
        hreflist = html.xpath("//td[@height='1']/../../tr[last()]//a/@href")

        if not hreflist:
            print("------------页面存在变化------------")
            return False

        # 获取最大页数
        maxnum = len(hreflist)

        if  int(num) > maxnum or int(num)<0:
            print("------------输入期次异常，请输入正确期次------------")
            return False
        href = hreflist[::-1][int(num)-1].replace("..","")

        # 构建下一个url连接
        nexturl = 'http://sioc-journal.cn/Jwk_hxxb/CN' + href
        try:
            response = requests.get(nexturl, hdrs, timeout=60)
        except:
            print('--------页面访问失败------------')
            return False

        soup = BeautifulSoup(response.text, 'lxml')
        all_td = soup.find_all('div', class_='issue-item_metadata')
        for td in all_td:
            ta = td.find('span',class_ ='j-pdf').find("a")
            titletext = td.find('div', class_='abs_njq', ).text

            titlelist = titletext.split(',')

            title = titlelist[-1].replace('pp', '').strip()
            title = title.split("DOI")[0].strip()

            href = ta.get('onclick')

            list = href.split(',')

            htmlid = list[1]

            id = htmlid.replace('\'', '')

            pdfurl = "http://sioc-journal.cn/Jwk_hxxb/CN/article/downloadArticleFile.do?attachType=PDF&id=%s" % id

            print('-----------开始下载-------------: %s' % title)
            pdfFilePath = Parent.makedir(self.journal, years, str(num),title,pdfRoot)
            if pdfFilePath == 1:
                self.suc += 1
                continue
            fig = Parent.getPdf(pdfurl, title, pdfFilePath,hdrs)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                self.journal, years, num, title.strip())
                line = line + '\n'
                Parent.Record(line,self.journal)
                # print(line)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1
                line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                self.journal, years, num, len(all_td), self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line,self.journal)
        Parent.Record("\n", self.journal)
        return  True

# if __name__ == '__main__':
#     j = jwk_hxxb()
#     j.getpdf("2019","12",'./')


from typing import List

import pymongo
from pymongo import ReadPreference
from pymongo.results import InsertOneResult, InsertManyResult


class BasePyMongo(object):

    def __init__(self, conn=None, dbname=None):
        self.conn_string = conn
        self.dbname = dbname
        if self.conn_string:
            self.conn()

    def conn(self):
        """
        mongodb://cjrw:vipdatacenter@192.168.31.220:27017/
        collection
        :return:
        """
        self.client = pymongo.MongoClient(self.conn_string)

    def auth(self, username, password, mechanism='SCRAM-SHA-1'):
        """
            mongoDB有不同的认证机制，3.0版本以后采用的是'SCRAM-SHA-1', 之前的版本采用的是'MONGODB-CR'。所以，以我的版本情况，显然应该用'MONGODB-CR'
        :param username:
        :param password:
        :param mechanism:
        :return:
        """
        self.db.authenticate(username, password, mechanism=mechanism)

    def use_db(self, db=None):
        if db:
            self.db = self.client[db]
        else:
            self.db = self.client[self.dbname]

    def get_database(self,db,read_preference=ReadPreference.SECONDARY_PREFERRED,**kwargs):
        if db:
            self.db = self.client.get_database(db,read_preference=read_preference,**kwargs)
        else:
            self.db = self.client.get_database(self.dbname,read_preference=read_preference,**kwargs)

    def show_dbs(self):
        """
        查询数据库列表
        database_names 在最新版本的 Python 中已废弃，Python3.7+ 之后的版本改为了 list_database_names()。
        :return:
        """
        dblist = self.client.list_database_names()
        return dblist

    def create_col(self, colname):
        """
        在 MongoDB 中，集合只有在内容插入后才会创建! 就是说，创建集合(数据表)后要再插入一个文档(记录)，集合才会真正创建。
        创建集合
        :return:
        """
        self.col = self.db[colname]

    def get_all_col(self):
        """
        获取所有集合
        collection_names 在最新版本的 Python 中已废弃，Python3.7+ 之后的版本改为了 list_collection_names()。
        :return:
        """
        collist = self.db.list_collection_names()
        return collist

    def insert_one(self, dicts, *args, **kwargs):
        """
        插入一条数据
        :param dicts:
        :param args:
        :param kwargs:
        :return:
        """
        return self.col.insert_one(dicts, *args, **kwargs )

    def get_insert_id(self, insertresult: InsertOneResult):
        """
        返回_id
        :param insertresult:
        :return:
        """
        return insertresult.inserted_id

    def insert_many(self, lists: List[dict], ordered=False, *args, **kwargs):
        """
        插入多条 直接返回插入的id
        指定id 插入时 dict里面需要包含{"_id":1}这样的格式
        :param lists:
        :param ordered: 如果某一条出现错误 设置为False会继续处理其他数据，默认为true
        :param args:
        :param kwargs:
        :return: InsertManyResult
        """
        list_result = self.col.insert_many(lists, ordered=False, *args, **kwargs)
        return list_result

    def get_insert_many_ids(self, list_result: InsertManyResult, *args, **kwargs):
        return list_result.inserted_ids

    def find_one(self, query=None):
        """
        查询一条
        :return:
        """
        if query is None:
            query = {}
        return self.col.find_one(query)

    def find(self, query=None, feild=None, limit=None):
        """
        查询所有
        feild = { "_id": 0, "name": 1, "alexa": 1 }
        除了 _id 你不能在一个对象中同时指定 0 和 1，如果你设置了一个字段为 0，则其他都为 1，反之亦然。

        以下实例除了 alexa 字段外，其他都返回：

        { "alexa": 0 }
        以下代码同时指定了 0 和 1 则会报错：
        ,{ "name": 1, "alexa": 0 }

        条件
        { "name": 1, "alexa": 0 }
        :return:
        """
        if query is None:
            query = {}
        if feild:
            my_result = self.col.find(query, feild)
        else:
            my_result = self.col.find(query)

        if limit:
            my_result = my_result.limit(limit)

        return my_result

    def update_one(self, query, newvalues):
        """
        更新一条
        :param query:
        :param newvalues:
        :return:
        """
        return self.col.update_one(query, newvalues)

    def update_many(self, query, newvalues):
        """
        更新多条
        :param query:
        :param newvalues:
        :return:
        """
        return self.col.update_many(query, newvalues)

    def sort(self, keys, sorts=-1):
        """
        查询出来的排序
        :param keys:
        :param sorts:
        :return:
        """
        return self.col.find().sort(keys, sorts)

    def delete(self, query):
        """
        删除一条
        :param query:
        :return:
        """
        return self.col.delete_one(query)

    def delete_many(self, query):
        """
        删除多条
        :param query:
        :return:
        """
        return self.col.delete_many(query)

    def delet_all(self):
        """
        x.deleted_count 删除数
        :return:
        """
        return self.col.delete_many({})

    def delete_col(self):
        """
        删除表
        :return:
        """
        return self.col.drop()



import time


def set_school_list_proxy(self):
    """
    使用该函数条件, self为类的对象
    代理在 proxyset set里
    使用的是bshttpx这个变量
    """
    try:
        proxy = self.proxyset.pop()
        self.logger.info("proxy is:{},proxy size is: {}".format(proxy, len(self.proxyset)))
        return self.bshttpx.creat_sn(proxy=proxy,
                                     headers=self.headers,
                                     verify=False)
    except KeyError as e:
        time.sleep(15)
        if str(e) == "'pop from an empty set'":
            self.proxyset = set(self.school_proxy_list)
            return self.set_school_list_proxy()


# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 10:12
# @Author  : suhong
# @File    : bulletin.py
# @Software: PyCharm

# 1.中国科学院院刊

import sys

import re
import requests
from bs4 import BeautifulSoup
from parsel import Selector
import  parent

hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer": "http://www.bulletin.cas.cn/zgkxyyk/ch/reader/issue_list.aspx",
        }

Parent = parent.Parent()

class Bulletin(object):

    def __init__(self):
        self.journal = '中国科学院院刊'
        self.base_url = "http://www.bulletin.cas.cn/zgkxyyk/ch/reader/"
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.all_num = 0

    def getpdf(self, years, num, pdfRoot):
        years = str(years)
        num = str(num)
        url  = "http://www.bulletin.cas.cn/zgkxyyk/ch/reader/issue_list.aspx"
        print(url)
        try:
            data = {
                'year_id': years,
                'quarter_id': num
            }
            r = requests.post(url, headers=hdrs,data=data, timeout=60)
        except:

            print('---------------访问失败--------------')
            return False
        line = 'No.' + str(num)
        print(line)

        soup = BeautifulSoup(r.text, 'lxml')
        tr_list = soup.find_all('tr',class_='listtr')
        self.all_num = len(tr_list)
        title = 1
        for tr in tr_list:
            pdfurl = self.base_url + tr.find_all('td')[3].find("a").get('href')

            print('-----------开始下载-------------: %s' % title)
            pdfFilePath = Parent.makedir(self.journal, years, str(num), str(title), pdfRoot)
            if pdfFilePath == 1:
                self.suc += 1
                continue
            fig = Parent.getPdf(pdfurl, title, pdfFilePath, hdrs)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                    self.journal, years, num, str(title))
                line = line + '\n'
                Parent.Record(line, self.journal)
                # print(line)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1
                line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                    self.journal, years, num, self.all_num, self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line, self.journal)
                title +=1
        Parent.Record("\n", self.journal)
        return True

# if __name__ == '__main__':
#     b = Bulletin()
#     b.getpdf("2020",'9','./')


# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 10:12
# @Author  : suhong
# @File    : jos.py
# @Software: PyCharm
import sys

import requests
from urllib import parse
import parent
from bs4 import BeautifulSoup

# 软件学报

hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer" :"http://www.jos.org.cn/",

}
Parent = parent.Parent()

class Jos(object):


    def __init__(self):
        self.url = 'http://www.jos.org.cn/jos/ch/reader/issue_browser.aspx'
        self.ero = 0
        self.suc = 0
        self.cnt = 0

        self.journal = '软件学报'

    def getpdf(self,years, num,pdfRoot):
        years = str(years)
        num = str(num)
        url = 'http://www.jos.org.cn/jos/ch/reader/issue_list.aspx?year_id=%s&quarter_id=%s' % (years, num)

        try:
            r = requests.get(url, headers=hdrs, timeout= 100)
        except:

            print('---------访问页面失败-----------')
            return False
        soup = BeautifulSoup(r.text, 'lxml')
        all_table = soup.find_all('table', id='table24')
        title = ''
        # print(all_table)
        # with open("./jos.html", "w", encoding="utf-8") as f:
        #     print("写入成功")
        #     f.write(r.content.decode())
        downlist=[]
        titlenum = 0

        for table in all_table[1:]:
            all_td = table.find_all('a', target='_blank')


            print("first pdf:%s" % self.cnt)
            for ta in all_td:


                b = ta.find('b')
                if b.text.upper() != 'PDF':
                    continue

                self.cnt +=1
        # print("first pdf:%s" % self.cnt)
        for table in all_table[1:]:
            all_td = table.find_all('a', target='_blank')



            for ta in all_td:


                b = ta.find('b')
                if b.text.upper() != 'PDF':
                    continue
                pagedtad = ta.parent.text.strip()
                downlist.append("1")

                list = pagedtad.split('[')
                data = list[0]
                title = data.split(':')[1].strip()

                if num == "0" and years =="0":

                    titlenum += 1
                    title = str(titlenum)
                if title =="0":
                    titlenum += 1
                    title = str(titlenum)
                if len(title.strip()) == 0:
                    title = table.previous_sibling.text
                href = ta.get('href')
                parseResult = parse.urlparse(href)
                param_dict = parse.parse_qs(parseResult.query)
                id = param_dict['file_no'][0]
                pdfurl = 'http://www.jos.org.cn/jos/ch/reader/create_pdf.aspx?file_no=%s&year_id=%s&quarter_id=%s&falg=1' % (
                id, years, num)
                # print(pdfurl)
                print(pdfurl)
                print('--------开始下载---------: %s' % title)

                pdfFilePath = Parent.makedir(self.journal, years, str(num), title, pdfRoot)
                if pdfFilePath == 1:
                    self.suc += 1
                    continue
                fig = Parent.getPdf(pdfurl, title, pdfFilePath, hdrs)
                # self.cnt = len(downlist)
                # print("self.cnt:%s"%self.cnt)
                if fig == -1:
                    self.ero += 1
                    line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                        self.journal, years, num, title.strip())
                    line = line + '\n'
                    Parent.Record(line, self.journal)
                if fig == 1:
                    print('%s,pdf下载成功' % title)
                    self.suc += 1

                    line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                        self.journal, years, num, self.cnt, self.suc, self.ero)
                    line = line + '\n'
                    Parent.Record(line, self.journal)
            # self.cnt = len(downlist)
            print('journal: %s, vol: %s。共有文章 %d；' % (
                self.journal,num, self.cnt))

        # 下载封面
        print("--------------------开始下载封面------------------")
        data = '00' + num
        href = ''
        url = 'http://www.jos.org.cn/jos/ch/reader/view_fixed_content.aspx?id=gqfm'
        titlename = '%s年第%s期' % (years, data[-2:])
        # print(titlename)

        try:
            r = requests.get(url, headers=hdrs, timeout= 100)
        except:

            print('----------访问失败----------------')

        soup = BeautifulSoup(r.text, 'lxml')
        span = soup.find('span', id ='Content')

        all_a = span.find_all('a')

        fmurl=""
        for ta in all_a:

            if ta.text.strip()  == titlename:

                href = ta.get('href')

                fmurl = href
            if num.find("K") != -1 or num.find("k") != -1:


                titlename = '%s年' % (years)

                # print('%s年第%s期' % (years, data[-2:]))
                # print(ta.text.strip())

                if ta.text.strip() == titlename +"增刊":
                    #print("增刊")

                    href = ta.get('href')

                    fmurl = href

                elif ta.text.strip() == titlename +"ZK期":
                    #print("zk期")
                    href = ta.get('href')

                    fmurl = href
                elif ta.text.strip() == titlename + "增刊2":
                    #print("增刊2")
                    href = ta.get('href')

                    fmurl = href
                elif ta.text.strip() == titlename + "增刊1":
                    #print("增刊1")
                    href = ta.get('href')

                    fmurl = href
                elif ta.text.strip() == titlename + "第ZK期":
                    #print("增刊1")
                    href = ta.get('href')

                    fmurl = href

        if fmurl=="":
            print("--------------下载封面存在特殊情况,请检查---------------%s,%s"%(years, str(num)))
            if num == "0" and years == "0":
                print("------------经检查，0年0期无封面下载----------")
                endline = ""
                Parent.Record(endline, self.journal)
                return True
            return False
        if fmurl.find("www") ==-1:
            fmurl = "http://www.jos.org.cn" +fmurl

        print("---------封面链接---------%s"%fmurl)
        pdfFilePath = Parent.makedir(self.journal, years, str(num), years+"_"+str(num), pdfRoot)
        if pdfFilePath == 1:
            self.suc += 1
            return False
        print("当前封面下载链接：%s"%fmurl)
        fig = Parent.getPdf(fmurl, years+"_"+str(num), pdfFilePath, hdrs)
        if fig == -1:
            self.ero += 1
            line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                self.journal, years, num, (years+"_"+str(num)).strip())
            line = line + '\n'
            Parent.Record(line, self.journal)
        if fig == 1:
            print('%s,pdf下载成功' % (years+"_"+str(num)))
            self.suc += 1

            line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                self.journal, years, num, self.cnt, self.suc, self.ero)
            line = line + '\n'
            Parent.Record(line, self.journal)

        Parent.Record("\n", self.journal)
        return True

# if __name__ == '__main__':
#     work = Jos()
#     work.getpdf("2019","9","./")





USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.106 Safari/537.36'

USER_AGENTS = [
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.62 Safari/537.36",
    "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; AcooBrowser; .NET CLR 1.1.4322; .NET CLR 2.0.50727)",
    "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Acoo Browser; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)",
    "Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.5; AOLBuild 4337.35; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)",
    "Mozilla/5.0 (Windows; U; MSIE 9.0; Windows NT 9.0; en-US)",
    "Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET CLR 2.0.50727; Media Center PC 6.0)",
    "Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET CLR 1.0.3705; .NET CLR 1.1.4322)",
    "Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.30)",
    "Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN) AppleWebKit/523.15 (KHTML, like Gecko, Safari/419.3) Arora/0.3 (Change: 287 c9dfb30)",
    "Mozilla/5.0 (X11; U; Linux; en-US) AppleWebKit/527+ (KHTML, like Gecko, Safari/419.3) Arora/0.6",
    "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2pre) Gecko/20070215 K-Ninja/2.1.1",
    "Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.9) Gecko/20080705 Firefox/3.0 Kapiko/3.0",
    "Mozilla/5.0 (X11; Linux i686; U;) Gecko/20070322 Kazehakase/0.4.5",
    "Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.8) Gecko Fedora/1.9.0.8-1.fc10 Kazehakase/0.5.6",
    "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/535.20 (KHTML, like Gecko) Chrome/19.0.1036.7 Safari/535.20",
    "Opera/9.80 (Macintosh; Intel Mac OS X 10.6.8; U; fr) Presto/2.9.168 Version/11.52",
]


def set_proxy(proxy):
    Proxiesss = {
        'http': proxy,
        'https': proxy
    }
    return Proxiesss


def set_proxy_aio(proxy):
    if proxy:
        return r"http://" + proxy
    return None


def set_proxy_httpx(proxy):
    if proxy:
        Proxiesss = {
            'http': "http://" + proxy,
            'https': "http://" + proxy
        }
        return Proxiesss
    else:
        return None


class MsgCode(object):
    NO_RESOURCE: int = 421  # 网页明确表明无资源
    PAGE_BLANK: int = 420  # 网页空白页
    END_STRING_ERROR: int = 210  # html结尾验证错误
    MARK_ERROR: int = 211  # 验证html错误，验证没有通过
    NOT_IS_JSON: int = 212  # 验证返回是否是json
    VER_CODE: int = 213  # 需要验证码
    TIME_OUT_ERROR: int = 408  # 超时错误
    PROXY_ERROR: int = 420  # 代理错误
    ON_KNOW: int = 1000  # 未知错误

    MONGO_ERROR: int = 1000  # mongodb 錯誤系列由1000 到 1100


SUCCESS = "SUCCESS"
FAILED = "FAILED"



"""
多文件合并到压缩文件
方法一：按行读取写入
方法二: 按块读取写入

"""

###########################################
# 同项目调用基础包
import os
import sys

filepath = os.path.abspath(__file__)
pathlist = filepath.split(os.sep)
pathlist = pathlist[:-4]
TopPath = os.sep.join(pathlist)
sys.path.insert(0, TopPath)
print(TopPath)
############################################

import time
import gzip

from re_common.baselibrary.utils.basedir import BaseDir
from re_common.baselibrary.utils.basefile import BaseFile


class MergeGzFile(object):
    def __init__(self):
        self.outPathFile = None
        self.a_num = 1000
        self.b_num = 20000

        self.a_size = 1024 * 1024 * 1024
        self.block_size = 2 * 1024 * 1024 * 1024


    def get_outpathfile(self,dst):
        BaseDir.create_dir(dst)
        now_time = time.strftime('%Y%m%d', time.localtime())
        self.filename = "{}.gz".format(now_time)
        self.outPathFile = BaseFile.get_new_path(dst,self.filename)
        return self.outPathFile


    def line_all_2_one_gz(self,src,dst,dst_size=None,a_num=None,b_num=None):
        """
        :param src: 输入路径
        :param dst: 输出路径
        :param dst_size:  指定输出文件的最大值
        :param a_num:  打印条数的取值（默认1000条输出一次信息）
        :param b_num:  打印路径的取值（默认20000条输出一次信息）
        :return:
        """
        # 程序开始时间
        StartTime = time.time()
        if a_num is None:
            a_num = self.a_num
        if b_num is None:
            b_num = self.b_num
        count_all = 0
        dst_count = 0
        src_file_num = 0
        src_file_location = 0
        if self.outPathFile is None:
            self.get_outpathfile(dst)

        f = gzip.open(self.outPathFile, "wb")

        for files in BaseDir.get_dir_all_files(src):
            src_file_num += 1

        for files in BaseDir.get_dir_all_files(src):
            # 处理每个文件的开始时间
            start_time = time.time()
            src_file_location += 1
            print("next source_path:"+files)

            count = 0
            for line in BaseFile.read_file_rb_mode_yield(files):
                count += 1
                count_all +=1
                dst_count +=1

                f.write(line)

                if count % a_num == 1:
                    print("process_src:%d/%d, Time total:%s, source_count: %d, dst_count: %d, allcount: %d" % (src_file_location, src_file_num, (repr(time.time() - start_time)), count, dst_count, count_all))
                if count % b_num == 1:
                    print("source_path: %s , dst_path:%s" % (files,self.outPathFile))
                if dst_size is not None:
                    if BaseFile.get_file_size(self.outPathFile) >= dst_size:
                        f.close()
                        print("cut dst file, now:source_count: %d,dst_count: %d, allcount: %d" % (count, dst_count, count_all))
                        dst_count = 0
                        self.outPathFile = BaseFile.change_file(self.outPathFile, size=dst_size,ending='gz')
                        # self.outPathFile = self.outPathFile.replace(".big_json",'.gz')
                        f = gzip.open(self.outPathFile, "wb")
                        print("new dst_path: %s" % self.outPathFile)

            print("finish one file;Time total:%s, process_src:%d/%d, source_count: %d, dst_count: %d, allcount: %d" % (repr(time.time() - start_time),src_file_location, src_file_num,count, dst_count, count_all))
        # 程序结束花费时间时间
        print('\nProce Over\nTime total:' + repr(time.time() - StartTime) + '\n')

    def block_all_2_one_gz(self,src,dst,dst_size=None,block_size=None,a_size=None):
        """
        按块读取小文件，并写入文件
        :param src: 输入路径
        :param dst: 输出路径
        :param source_size: 输入文件大于source_size，就直接复制过去
        :param dst_size: 指定输出文件的最大值（但是需要操作完一个输入文件后判断大小）
        :param block_size: 按块读取的值
        :param a_size: 打印路径的取值（默认1G大小输出一次信息）
        :return:
        """
        # 程序开始时间
        StartTime = time.time()
        src_file_num = 0
        src_all_size = 0
        src_file_location = 0
        if a_size is None:
            a_size = self.a_size
        if block_size is None:
            block_size = self.block_size

        if self.outPathFile is None:
            self.get_outpathfile(dst)

        f = gzip.open(self.outPathFile, "wb")

        for files in BaseDir.get_dir_all_files(src):
            src_file_num += 1
        for files in BaseDir.get_dir_all_files(src):
            # 处理每个文件的开始时间
            src_all_size += BaseFile.get_file_size(files)
            dst_file_size = 0
            start_time = time.time()
            src_file_location += 1
            print("next source_path:" + files)

            for block in BaseFile.read_file_rb_block(files,BLOCK_SIZE=block_size):
                f.write(block)

            if BaseFile.get_file_size(self.outPathFile) % a_size == 1:
                print("process_src:%d/%d, dst_size:%d, src_size:%d, src_all_size:%d, Time total:%.2f/%.2f" % (src_file_location, src_file_num, dst_file_size ,BaseFile.get_file_size(files), src_all_size, (time.time() - start_time),(time.time() - StartTime) ))
            dst_file_size = BaseFile.get_file_size(self.outPathFile)
            print("finish one file;process_src:%d/%d, dst_size:%d, src_size:%d, src_all_size:%d, Time total:%.2f/%.2f" % (src_file_location, src_file_num, dst_file_size ,BaseFile.get_file_size(files), src_all_size, (time.time() - start_time),(time.time() - StartTime) ))
            if dst_size is not None:
                if BaseFile.get_file_size(self.outPathFile) >= dst_size:
                    f.close()
                    self.outPathFile = BaseFile.change_file(self.outPathFile, size=dst_size,ending='gz')
                    f = gzip.open(self.outPathFile, "wb")
                    print("new dst_path: %s" % self.outPathFile)
                    dst_file_size = 0
            # 程序结束花费时间时间
        print('\nProce Over\nTime total:' + repr(time.time() - StartTime) + '\n')


if __name__ == '__main__':
    old_path = r'\\192.168.31.188\download\cnki_qk\download\get_ref\input'
    new_path = r'\\192.168.31.188\download\cnki_qk\download\get_ref\output'
    a = MergeGzFile()
    a.line_all_2_one_gz(old_path,new_path,dst_size=1024*1024*100)
    # a.block_all_2_one(old_path,new_path,dst_size=1024*1024*10)




"""
异步在python中的演变流程
"""

############################################################
# 第一步 python引入了迭代器的概念
############################################################

# 注意 iter 和 next方法
lists = [1, 2, 3, 4]
it = iter(lists)
print(next(it))
print(next(it))
print(next(it))
print(next(it))
print(next(it))  # StopIteration


# 类的迭代器实现
class MyNumbers(object):
    def __iter__(self):
        self.a = 1
        return self

    def __next__(self):
        if self.a <= 20:
            x = self.a
            self.a += 1
            return x
        else:
            raise StopIteration


myclass = MyNumbers()
myiter = iter(myclass)

for x in myiter:
    print(x)

############################################################
# 第二步 python引入了生成器的概念
############################################################


import sys


def fibonacci(n):  # 生成器函数 - 斐波那契
    a, b, counter = 0, 1, 0
    while True:
        if (counter > n):
            return
        yield a
        a, b = b, a + b
        counter += 1


f = fibonacci(10)  # f 是一个迭代器，由生成器返回生成

while True:
    try:
        print(next(f), end=" ")
    except StopIteration:
        sys.exit()
        break


# 使用了 yield 的函数被称为生成器
def consumer():
    r = 'start'
    while True:
        print("yield first")
        n = yield r
        print("n is %s,r is %s" % (n, r))
        print("yield end")
        if not n:
            return
        print('[CONSUMER] Consuming %s...' % n)
        r = '200 OK'


def produce(c):
    """
    由于生成器迭代器从生成器功能主体的顶部开始执行，因此在刚刚创建生成器时，没有yield表达式来接收值。
    因此，在生成器迭代器刚刚启动时，禁止使用non-None参数调用send（），如果发生这种情况，
    则引发TypeError（可能是由于某种逻辑错误）。因此，在与协程进行通信之前，
    必须首先调用next（）或send（None）将其执行推进到第一个yield表达式
    """
    re = c.send(None)
    print("************" + re)
    n = 0
    while n < 5:
        n = n + 1
        print('[PRODUCER] Producing %s...' % n)
        r = c.send(n)
        print('[PRODUCER] Consumer return: %s' % r)
    c.close()


c = consumer()
produce(c)


############################################################
# 第三步 python增强了生成器，引入 yield from
############################################################



# https://www.cnblogs.com/wongbingming/p/9085268.html
# yield from 是在Python3.3才出现的语法
# yield from 后面需要加的是可迭代对象，它可以是普通的可迭代对象，也可以是迭代器，甚至是生成器。

# 字符串
astr = 'ABC'
# 列表
alist = [1, 2, 3]
# 字典
adict = {"name": "wangbm", "age": 18}
# 生成器
agen = (i for i in range(4, 8))


def gen(*args, **kw):
    for item in args:
        for i in item:
            yield i


new_list = gen(astr, alist, adict, agen)
print(list(new_list))


# ['A', 'B', 'C', 1, 2, 3, 'name', 'age', 4, 5, 6, 7]

# 使用yield from
def gen(*args, **kw):
    for item in args:
        yield from item


new_list = gen(astr, alist, adict, agen)
print(list(new_list))


# ['A', 'B', 'C', 1, 2, 3, 'name', 'age', 4, 5, 6, 7]
# 由上面两种方式对比，可以看出，yield from后面加上可迭代对象，他可以把可迭代对象里的每个元素一个一个的yield出来，对比yield来说代码更加简洁，结构更加清晰。

# 生成器的嵌套

# 1、调用方：调用委派生成器的客户端（调用方）代码
# 2、委托生成器：包含yield from表达式的生成器函数
# 3、子生成器：yield from后面加的生成器函数
# 子生成器
def average_gen():
    total = 0
    count = 0
    average = 0
    while True:
        new_num = yield average
        count += 1
        total += new_num
        average = total / count


# 委托生成器
def proxy_gen():
    while True:
        yield from average_gen()


# 调用方
def main():
    calc_average = proxy_gen()
    next(calc_average)  # 预激下生成器
    print(calc_average.send(10))  # 打印：10.0
    print(calc_average.send(20))  # 打印：15.0
    print(calc_average.send(30))  # 打印：20.0


main()


# 子生成器
def average_gen():
    total = 0
    count = 0
    average = 0
    while True:
        new_num = yield average
        if new_num is None:
            break
        count += 1
        total += new_num
        average = total / count

    # 每一次return，都意味着当前协程结束。
    return total, count, average


# 委托生成器
def proxy_gen():
    while True:
        # 只有子生成器要结束（return）了，yield from左边的变量才会被赋值，后面的代码才会执行。
        total, count, average = yield from average_gen()
        print("计算完毕！！\n总共传入 {} 个数值， 总和：{}，平均数：{}".format(count, total, average))


# 调用方
def main():
    calc_average = proxy_gen()
    next(calc_average)  # 预激协程
    print(calc_average.send(10))  # 打印：10.0
    print(calc_average.send(20))  # 打印：15.0
    print(calc_average.send(30))  # 打印：20.0
    calc_average.send(None)  # 结束协程
    # 如果此处再调用calc_average.send(10)，由于上一协程已经结束，将重开一协程


main()


############################################################
# 第四步 python引入asyncio
############################################################

# asyncio是Python 3.4版本引入的标准库，直接内置了对异步IO的支持。
#
# asyncio的编程模型就是一个消息循环。我们从asyncio模块中直接获取一个EventLoop的引用，然后把需要执行的协程扔到EventLoop中执行，就实现了异步IO。
#
# 用asyncio实现Hello world代码如下：

import asyncio


@asyncio.coroutine
def hello():
    print("Hello world!")
    # 异步调用asyncio.sleep(1):
    r = yield from asyncio.sleep(1)
    print("Hello again!")


# 获取EventLoop:
loop = asyncio.get_event_loop()
# 执行coroutine
loop.run_until_complete(hello())
loop.close()

# @asyncio.coroutine把一个generator标记为coroutine类型，然后，我们就把这个coroutine扔到EventLoop中执行。
#
# hello()会首先打印出Hello world!，然后，yield from语法可以让我们方便地调用另一个generator。由于asyncio.sleep()也是一个coroutine，所以线程不会等待asyncio.sleep()，而是直接中断并执行下一个消息循环。当asyncio.sleep()返回时，线程就可以从yield from拿到返回值（此处是None），然后接着执行下一行语句。
#
# 把asyncio.sleep(1)看成是一个耗时1秒的IO操作，在此期间，主线程并未等待，而是去执行EventLoop中其他可以执行的coroutine了，因此可以实现并发执行。
#
# 我们用Task封装两个coroutine试试：

import threading
import asyncio


@asyncio.coroutine
def hello():
    print('Hello world! (%s)' % threading.currentThread())
    yield from asyncio.sleep(1)
    print('Hello again! (%s)' % threading.currentThread())


loop = asyncio.get_event_loop()
tasks = [hello(), hello()]
loop.run_until_complete(asyncio.wait(tasks))
loop.close()

"""
Hello world! (<_MainThread(MainThread, started 140735195337472)>)
Hello world! (<_MainThread(MainThread, started 140735195337472)>)
(暂停约1秒)
Hello again! (<_MainThread(MainThread, started 140735195337472)>)
Hello again! (<_MainThread(MainThread, started 140735195337472)>)
"""

############################################################
# 第五步 使用python内部关键词替换，变得简便
############################################################
# 用asyncio提供的@asyncio.coroutine可以把一个generator标记为coroutine类型，然后在coroutine内部用yield from调用另一个coroutine实现异步操作。

# 为了简化并更好地标识异步IO，从Python 3.5开始引入了新的语法async和await，可以让coroutine的代码更简洁易读。

# 请注意，async和await是针对coroutine的新语法，要使用新的语法，只需要做两步简单的替换：

# 把@asyncio.coroutine替换为async；
# 把yield from替换为await。
# 让我们对比一下上一节的代码：
import asyncio


@asyncio.coroutine
def hello():
    print("Hello world!")
    r = yield from asyncio.sleep(1)
    print("Hello again!")


# 用新语法重新编写如下：

async def hello2():
    print("Hello world!")
    r = await asyncio.sleep(1)
    print("Hello again!")
# 剩下的代码保持不变

# 看下这篇　比较明白
# https://blog.csdn.net/Likianta/article/details/90123678


# -*- coding: utf-8 -*-
# @Time    : 2020/4/29 10:12
# @Author  : suhong
# @File    : actasc.py
# @Software: PyCharm

# 1.环境科学学报

import sys

import re
import requests
from bs4 import BeautifulSoup
from parsel import Selector
import parent

hdrs = {
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
    "Referer": "http://www.actasc.cn/hjkxxb/ch/reader/issue_list.aspx",
    }

Parent = parent.Parent()


class Actasc(object):

    def __init__(self):
        self.url = 'http://www.actasc.cn/hjkxxb/ch/index.aspx'
        self.journal = '环境科学学报'
        self.base_url = "http://www.actasc.cn/hjkxxb/ch/reader/"
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.all_num = 0

    def getpdf(self, years, num, pdfRoot):
        years = str(years)
        num = str(num)
        url = "http://www.actasc.cn/hjkxxb/ch/reader/issue_list.aspx"
        print(url)
        try:
            data = {
                'year_id': years,
                'quarter_id': num
            }
            r = requests.post(url, headers=hdrs, data=data, timeout=60)
        except:

            print('---------------访问失败--------------')
            return False
        line = 'No.' + str(num)
        print(line)

        soup = BeautifulSoup(r.text, 'lxml')
        all_table = soup.find_all('table', id='table24')
        if len(all_table) == 1:
            print("年份或者期刊错误")
            return False
        for table in all_table:
            for tr in table.find_all("tr"):
                a_num = len(tr.find_all("a"))
                if a_num == 3:
                    self.all_num += 1
                    continue
                continue
                # 当a_num == 3 就是包含信息的tr
        for table in all_table:
            for tr in table.find_all("tr"):
                a_num = len(tr.find_all("a"))
                if a_num == 3:
                    pdfurl = self.base_url + tr.find_all('td')[1].find_all('a')[2].get('href')
                    info = tr.find_all('td')[1].get_text()
                    info_pa = ':(.*) \[摘要\]'
                    title = re.findall(info_pa, info)[0]

                    print('-----------开始下载-------------: %s' % title)
                    if title == '0':
                        title = '0-封面+目录'
                    pdfFilePath = Parent.makedir(self.journal, years, str(num), title, pdfRoot)
                    if pdfFilePath == 1:
                        self.suc += 1
                        continue
                    fig = Parent.getPdf(pdfurl, title, pdfFilePath, hdrs)
                    if fig == -1:
                        self.ero += 1
                        line = 'journal: %s, years: %s, issue: %s: %s 下载失败' % (
                            self.journal, years, num, title.strip())
                        line = line + '\n'
                        Parent.Record(line, self.journal)
                        # print(line)
                    if fig == 1:
                        print('%s,pdf下载成功' % title)
                        self.suc += 1
                        line = 'journal: %s, years: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                            self.journal, years, num, self.all_num, self.suc, self.ero)
                        line = line + '\n'
                        Parent.Record(line, self.journal)
        Parent.Record("\n", self.journal)
        return True
# if __name__ == '__main__':
#     a = Actasc()
#     a.getpdf("2017","1",'1')



import sqlite3

from re_common.baselibrary.database.moudle import Sqlite3Moudle
from re_common.baselibrary.database.sql_factory import SqlFactory
from re_common.baselibrary.utils.basedict import BaseDicts


class Sqlite3(SqlFactory):
    def __init__(self):
        # 就是conn
        self.db = ''
        self.cursor = ''
        self.sqlite3_moudle = {}

    def set_encoding(self, bytes=False, encoding="gbk"):
        """
        https://blog.csdn.net/xkxjy/article/details/8179479
        在不知道编码格式的情况下 使用bytes 但我没有成功
        :param bytes:
        :param encoding:
        :return:
        """
        # if bytes:
        #     self.db.text_factory = bytes
        # else:
        #     self.db.text_factory = lambda x: str(x, encoding, 'ignore')
        self.db.text_factory = lambda x: str(x, encoding, 'ignore')

    def link(self, sqlite3_moudle: Sqlite3Moudle):
        """
        连接数据库
        :param sqlite3_moudle:
        :param mysqlmoudle:
        :return:
        """
        self.sqlite3_moudle = sqlite3_moudle
        # 返回连接对象
        dicts = sqlite3_moudle.to_dict()
        dicts = BaseDicts.removeDictsNone(dicts)
        self.db = sqlite3.connect(**dicts)
        self.cursor = self.db.cursor()
        return self.db, self.cursor

    def get_cursor(self) -> sqlite3.Cursor:
        """
        本函数通过链接返回sqlite3的游标
        :param connect: 传入的是sqlite3的连接
        :return: 返回游标
        """
        assert isinstance(self.db, sqlite3.Connection)
        self.cursor = self.db.cursor()
        return self.cursor

    def execute(self, sql: str) -> sqlite3.Cursor:
        """
        通过游标对象执行sql语句并返回结果
        :param cursor: 游标对象
        :param sql:  需要执行的sql语句
        :return:  返回结果的游标对象
        """
        assert isinstance(self.cursor, sqlite3.Cursor)
        result = self.cursor.execute(sql)
        return result

    def executemany(self, sql: str, seq_of_parameters) -> sqlite3.Cursor:
        assert isinstance(self.cursor, sqlite3.Cursor)
        result = self.cursor.executemany(sql, seq_of_parameters)
        return result

    def get_all_field_info(self, tablename):
        sql = "PRAGMA table_info({})".format(tablename)
        result = self.execute(sql)
        return result.fetchall()

    def get_all_field(self, tablename):
        listinfo = self.get_all_field_info(tablename)
        return [row[1] for row in listinfo]

    def get_rowcount(self, ) -> int:
        """
        获取sql语句影响的行数
        :param cursor: 游标对象
        :return:  影响的行数
        """
        assert isinstance(self.cursor, sqlite3.Cursor)
        num = self.cursor.rowcount
        return num

    def close_cursor(self) -> None:
        """
        关闭游标
        :param cursor: 游标
        :return: None
        """
        assert isinstance(self.cursor, sqlite3.Cursor)
        self.cursor.close()

    def my_commit(self) -> None:
        """
        提交
        :param connect: 连接
        :return: None
        """
        assert isinstance(self.db, sqlite3.Connection)
        self.db.commit()

    def close_connect(self) -> None:
        """
        链接关闭
        :param connect: 连接
        :return: None
        """
        assert isinstance(self.db, sqlite3.Connection)
        self.db.close()

    def __del__(self):
        self.close_connect()


    @classmethod
    def sqlite3_merge(cls, inpath, attachpath, tablename="modify_title_info_zt"):
        """
        合并两个db3
        :param inpath:
        :param attachpath:
        :return:
        """
        conn = sqlite3.connect(inpath)
        conn.text_factory = str
        cur = conn.cursor()
        attach = 'attach database "' + attachpath + '" as w;'
        sql1 = 'insert into {} select * from w.{};'.format(tablename, tablename)
        cur.execute(attach)
        cur.execute(sql1)
        conn.commit()
        cur.close()
        conn.close()


    def create_table(self,tablename,fields:list):
        if self.cursor == '':
            self.get_cursor()
        sql = "PRAGMA foreign_keys = false;"
        self.execute(sql)
        sql = f'DROP TABLE IF EXISTS "{tablename}";'
        self.execute(sql)
        strings = ""
        for field in fields:
            strings = strings + f'"{field}" TEXT,'
        strings = strings.rstrip(',')
        sql = f'CREATE TABLE "{tablename}"({strings});'
        self.execute(sql)
        sql = 'PRAGMA foreign_keys = true;'
        self.execute(sql)


#!/usr/local/bin/python
# -*- coding:utf-8 -*-

# 由于每个配置必须要有root 所以这里有个root，但我们不使用他，因为在logger对象中无法获取root的hander
# 来设置过滤器，这里我们使用all代表文件和控制台的输出，配置文件的使用模式是在[loggers]中申明有哪些logger
# 在 [logger_xxx]中对应每个logger的配置，下面的结构完全遵循这一结构

import logging
import logging.config
import os
import time
from functools import wraps
from logging.handlers import TimedRotatingFileHandler, RotatingFileHandler
from os import path
import sys

"""
这个是logger的过滤器  可以过滤掉多余的日志 让对应级别的日志写入对应级别的文件
通过日志的级别和传入的级别对比 返回true or false
"""


class BaseLogFilter(logging.Filter):
    def __init__(self, name='', logname="_1"):
        super(BaseLogFilter, self).__init__(name)
        self.logname = logname


class LogLevelFilter(BaseLogFilter):
    def __init__(self, name='', level=logging.DEBUG, levels=None):
        super(LogLevelFilter, self).__init__(name)
        self.level = level
        self.levels = levels

    def filter(self, record):
        if self.levels == None:
            return record.levelno == self.level
        else:
            for level in self.levels:
                if record.levelno == level:
                    return True
            return False


"""
单例模式的一种实现
"""


def singleton(cls):
    instances = {}

    @wraps(cls)
    def getinstance(*args, **kw):
        if cls not in instances:
            instances[cls] = cls(*args, **kw)
        return instances[cls]

    return getinstance


"""
Logger的主体，主要靠这个实现
加入单例模式下遇到MLogger调用静态方法会出问题
"""


# @singleton
class MLogger(object):
    def __init__(self, logfiledir=None, filter=None):
        if logfiledir:
            # 获取logger实例，如果参数为空则返回root logger
            self.confFilePath(logfiledir)
        # 这是输出流
        self.streamoutlogger = self.streamOutLogger()
        # 这是错误流
        self.streamerrlogger = self.streamErrLogger()

        self.streamlogger = self.streamLogger()

        self._alllogger = None
        self._filelogger = None
        self._timerotatingfilelogger = None
        self._rotatingfilelogger = None
        self.fileter = filter

        self.maxBytes = 1024 * 1024 * 1024
        self.backupCount = 10

    def set_logfiledir(self, logfiledir):
        self.confFilePath(logfiledir)

    @property
    def alllogger(self):
        # logger 对象是alllogger 及所有日志对象
        if not self._alllogger:
            self._alllogger = self.allLogger(self.logfiledir)
        return self._alllogger

    @alllogger.setter
    def alllogger(self, value):
        self._alllogger = value

    @property
    def filelogger(self):
        if not self._filelogger:
            self._filelogger = self.fileLogger(self.logfiledir)
        return self._filelogger

    @filelogger.setter
    def filelogger(self, value):
        self._filelogger = value

    @property
    def timerotatingfilelogger(self):
        if not self._timerotatingfilelogger:
            self._timerotatingfilelogger = self.timeRotatingFileLogger(self.logfiledir, self.fileter)
        return self._timerotatingfilelogger

    @timerotatingfilelogger.setter
    def timerotatingfilelogger(self, value):
        self._timerotatingfilelogger = value

    @property
    def rotatingfilelogger(self):
        if not self._rotatingfilelogger:
            self._rotatingfilelogger = self.RotatingFileLogger(self.logfiledir, self.fileter, maxBytes=self.maxBytes,
                                                               backupCount=self.backupCount)
        return self._rotatingfilelogger

    @rotatingfilelogger.setter
    def rotatingfilelogger(self, value):
        self._rotatingfilelogger = value

    def confFilePath(self, path=None):
        """
        这里定义了log日志存放的目录
        :param path: log日志存放的路径 如果没有 就默认当前目录的logs文件夹 
        :return: 
        """
        if path is None or path == '':
            # 如果没有指定文件路径
            self.logfiledir = "./logs"
            if not os.path.exists(self.logfiledir):
                os.makedirs(self.logfiledir)
        else:
            try:
                if not os.path.exists(path):
                    os.makedirs(path)
                self.logfiledir = path
            except Exception as e:
                raise e

    @staticmethod
    def formatter():
        # fmt = "%(asctime)s %(levelname)s {%(message)s} %(pathname)s:%(funcName)s:%(lineno)s:%(module)s %(name)s %(processName)s:%(process)d %(threadName)s:%(thread)d"
        fmt = "[%(asctime)s %(levelname)s/%(processName)s:%(process)d/%(threadName)s:%(thread)d] %(message)s ==> %(pathname)s->%(module)s->%(funcName)s->%(lineno)s %(name)s"
        datefmt = "%a %d %b %Y %H:%M:%S"  # Thu 22 Feb 2018
        datefmt = "%Y-%m-%d %H:%M:%S"  # 2018-02-22
        formatter = logging.Formatter(fmt, datefmt)
        return formatter

    @staticmethod
    def BaseHandler(std, level, filter=None):
        # 错误流的handler warn及其以上
        streamerrhandler = logging.StreamHandler(std)
        if filter != None:
            # 添加过滤器
            streamerrhandler.addFilter(filter)
        # 获取输出格式
        streamerrhandler.setFormatter(MLogger.formatter())
        # 设置级别
        streamerrhandler.setLevel(level)
        return streamerrhandler

    @staticmethod
    def BaseFileHandler(level, filename, filter=None, encoding='utf-8'):
        fileHandler = logging.FileHandler(filename, encoding=encoding)
        if filter != None:
            fileHandler.addFilter(filter)
        fileHandler.setFormatter(MLogger.formatter())
        fileHandler.setLevel(level)
        return fileHandler

    # 错误流会输出WARN及以上的级别
    @staticmethod
    def streamErrHandlers():
        return MLogger.BaseHandler(sys.stderr, logging.WARN)

    @staticmethod
    def streamHandlers():
        return MLogger.BaseHandler(sys.stdout, logging.DEBUG)

    # 输出流只会输出INFO 和 DEBUG 两个级别的数据
    # https://yinzo.github.io/14610807170718.html 小坑
    @staticmethod
    def streamOutHandler():
        filter_stdout = LogLevelFilter(levels=[logging.INFO, logging.DEBUG])
        return MLogger.BaseHandler(sys.stdout, logging.DEBUG, filter_stdout)

    # 文件流会将所有级别的日志写入mylog.log这个文件
    @staticmethod
    def fileHandler(filepath):
        log_file_path = path.join(filepath, time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path)

    @staticmethod
    def timeRotatingFileHandler(filepath, filter=None):
        suffix = ""
        if filter != None:
            suffix = filter.logname
        log_file_path = path.join(filepath, time.strftime('%Y%m%d', time.localtime(time.time())) + suffix + ".log")
        hander = TimedRotatingFileHandler(log_file_path, when="D", interval=1, backupCount=30)
        if filter != None:
            # 添加过滤器
            hander.addFilter(filter)
        hander.setFormatter(MLogger.formatter())
        hander.setLevel(logging.DEBUG)
        return hander

    @staticmethod
    def RotatingFileHandler(filepath, filter=None, maxBytes=1024 * 1024 * 1024, backupCount=10):
        suffix = ""
        if filter != None:
            suffix = filter.logname
        log_file_path = path.join(filepath, time.strftime('%Y%m%d', time.localtime(time.time())) + suffix + ".log")
        hander = RotatingFileHandler(log_file_path, maxBytes=maxBytes, backupCount=backupCount)
        if filter != None:
            # 添加过滤器
            hander.addFilter(filter)
        hander.setFormatter(MLogger.formatter())
        hander.setLevel(logging.DEBUG)
        return hander

    """
    下面这些只会将对应级别的日志写入对应的文件
    """

    @staticmethod
    def fileDebugHandler(filepath):
        log_file_path = path.join(filepath,
                                  "mydebuglog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_debug = LogLevelFilter(level=logging.DEBUG)
        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_debug)

    @staticmethod
    def fileInfoHandler(filepath):
        log_file_path = path.join(filepath,
                                  "myinfolog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_info = LogLevelFilter(level=logging.INFO)

        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_info)

    @staticmethod
    def fileWarnHandler(filepath):
        log_file_path = path.join(filepath,
                                  "mywarnlog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_warn = LogLevelFilter(level=logging.WARN)

        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_warn)

    @staticmethod
    def fileErrorHandler(filepath):
        log_file_path = path.join(filepath,
                                  "myerrorlog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_error = LogLevelFilter(level=logging.ERROR)

        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_error)

    @staticmethod
    def fileExceptionHandler(filepath):
        log_file_path = path.join(filepath,
                                  "myexceptionlog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_exception = LogLevelFilter(level=logging.ERROR)  # 会返回错误堆栈

        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_exception)

    @staticmethod
    def fileCriticalHandler(filepath):
        log_file_path = path.join(filepath,
                                  "mycriticallog_" + time.strftime('%Y%m%d', time.localtime(time.time())) + ".log")
        filter_critical = LogLevelFilter(level=logging.CRITICAL)
        return MLogger.BaseFileHandler(logging.DEBUG, log_file_path, filter_critical)

    """
    下面是各种各样的logger 用于不同的输出
    比如你用errlogger就会只打印错误的logger 而不会打印输出信息的logger且不会写入文件 
    我们可以自由组合我们的logger方便使用，只要定义出不同组合的logger就行了，我现在一般使用allloger
    记录下所有的信息
    """

    @staticmethod
    def streamErrLogger():
        # 获取logger对象
        logger = logging.getLogger("streamErrLogger")
        # 设置logger获取的级别
        logger.setLevel(logging.DEBUG)
        logger.handlers = []
        # 为logger添加handler
        logger.addHandler(MLogger.streamErrHandlers())
        return logger

    @staticmethod
    def streamOutLogger():
        logger = logging.getLogger("streamOutLogger")
        logger.setLevel(logging.DEBUG)
        logger.handlers = []
        logger.addHandler(MLogger.streamOutHandler())
        return logger

    @staticmethod
    def allLogger(filepath):
        # 获取all代表不管输出和文件都会有流产生
        logger = logging.getLogger("all")
        logger.setLevel(logging.DEBUG)
        logger.handlers = []
        # http://www.aiuxian.com/article/p-483639.html
        logger.addHandler(MLogger.streamOutHandler())  # 输出流
        logger.addHandler(MLogger.streamErrHandlers())  # 错误流
        # 这是所有的日志都会输出到这个文件
        logger.addHandler(MLogger.fileHandler(filepath))
        # 下面是各个级别的日志流都会输入到对应的文件中
        logger.addHandler(MLogger.fileDebugHandler(filepath))
        logger.addHandler(MLogger.fileInfoHandler(filepath))
        logger.addHandler(MLogger.fileWarnHandler(filepath))
        logger.addHandler(MLogger.fileErrorHandler(filepath))
        logger.addHandler(MLogger.fileExceptionHandler(filepath))
        logger.addHandler(MLogger.fileCriticalHandler(filepath))
        return logger

    @staticmethod
    def multifile_logger(filepath):
        # 获取all代表不管输出和文件都会有流产生
        logger = logging.getLogger("multifile")
        logger.setLevel(logging.DEBUG)
        logger.handlers = []
        # 下面是各个级别的日志流都会输入到对应的文件中
        logger.addHandler(MLogger.fileDebugHandler(filepath))
        logger.addHandler(MLogger.fileInfoHandler(filepath))
        logger.addHandler(MLogger.fileWarnHandler(filepath))
        logger.addHandler(MLogger.fileErrorHandler(filepath))
        logger.addHandler(MLogger.fileExceptionHandler(filepath))
        logger.addHandler(MLogger.fileCriticalHandler(filepath))
        return logger

    @staticmethod
    def fileLogger(filepath):
        # 获取all代表不管输出和文件都会有流产生
        logger = logging.getLogger("file")
        logger.setLevel(logging.DEBUG)
        # 防止多次写入
        logger.handlers = []
        # http://www.aiuxian.com/article/p-483639.html
        logger.addHandler(MLogger.streamOutHandler())  # 输出流
        logger.addHandler(MLogger.streamErrHandlers())  # 错误流
        # 这是所有的日志都会输出到这个文件
        logger.addHandler(MLogger.fileHandler(filepath))
        return logger

    @staticmethod
    def timeRotatingFileLogger(filepath, fileter):
        # 获取all代表不管输出和文件都会有流产生
        logger = logging.getLogger("timerotatingfile")
        logger.setLevel(logging.DEBUG)
        # 防止多次写入
        logger.handlers = []
        # http://www.aiuxian.com/article/p-483639.html
        logger.addHandler(MLogger.streamOutHandler())  # 输出流
        logger.addHandler(MLogger.streamErrHandlers())  # 错误流
        if fileter:
            logger.addHandler(MLogger.timeRotatingFileHandler(filepath, fileter))
        # 这是所有的日志都会输出到这个文件
        logger.addHandler(MLogger.timeRotatingFileHandler(filepath))
        return logger

    @staticmethod
    def RotatingFileLogger(filepath, fileter, maxBytes=1024 * 1024 * 1024, backupCount=10):
        # 获取all代表不管输出和文件都会有流产生
        logger = logging.getLogger("rotatingfile")
        logger.setLevel(logging.DEBUG)
        # 防止多次写入
        logger.handlers = []
        # http://www.aiuxian.com/article/p-483639.html
        logger.addHandler(MLogger.streamOutHandler())  # 输出流
        logger.addHandler(MLogger.streamErrHandlers())  # 错误流
        if fileter:
            logger.addHandler(
                MLogger.RotatingFileHandler(filepath, fileter, maxBytes=maxBytes, backupCount=backupCount))
        # 这是所有的日志都会输出到这个文件
        logger.addHandler(MLogger.RotatingFileHandler(filepath, maxBytes=maxBytes, backupCount=backupCount))
        return logger

    def streamLogger(self):
        # 全局对象个数有getLogger的参数决定
        logger = logging.getLogger("streamLogger")
        logger.setLevel(logging.DEBUG)
        # 防止多次打印
        logger.handlers = []
        logger.addHandler(MLogger.streamHandlers())
        return logger

# def main():
#
#     # 使用教程
#     log_file_path = path.join(path.dirname(path.abspath(__file__)), 'logs')
#     logger = MLogger(log_file_path).streamlogger
#     logger.debug('debug message')
#     logger.info('info message')
#     logger.warning('warn message')
#     logger.error('error message')
#     logger.exception('exception message')
#     logger.critical('critical message')
#
# main()



# -*- coding: utf-8 -*-
# @Time    : 2019/7/14 15:15
# @Author  : qianjun
# @FileName: cltmt.py
# @Software: PyCharm

import sys
import time

import requests
import  parent
from urllib import parse
from bs4 import BeautifulSoup
from lxml import etree

# 汉语教学方法与技术
data = {}
hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer" :"https://engagedscholarship.csuohio.edu",

}
Parent = parent.Parent()
class cltmt(object):


    def __init__(self):
        self.url = 'https://engagedscholarship.csuohio.edu/cltmt/'
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.journal = '汉语教学方法与技术'

    def getpdf(self,vol, num,pdfRoot):
        vol = str(vol)
        num = str(num)
        url = 'https://engagedscholarship.csuohio.edu/cltmt/vol{}/iss{}'.format(vol,num)
        # data['year_id'] = years
        # data['quarter_id'] = num
        # print(years,num)
        # print(data)
        # print(url)

        try:
            r = requests.get(url, headers=hdrs,  timeout =60)

            time.sleep(5)
        except:
            print('---------------访问失败------------')
            return False

        bs = BeautifulSoup(r.text, 'lxml')

        if bs.find(class_='article-list'):

            if bs.find(class_='article-list').find_all(class_="doc"):
                self.cnt = len(bs.find(class_='article-list').find_all(class_="doc"))
                print('journal: %s, vol: %s, issue: %s。共有文章 %d；' % (
                        self.journal, vol, num, self.cnt))

                for infotag in bs.find(class_='article-list').find_all(class_="doc"):
                    pdfurl =""
                    title=""

                    if infotag.find(class_="pdf"):

                        # 获取pdf下载链接
                        pdfurl = "".join(infotag.find(class_="pdf").find("a")["href"])

                        # 获取所有的p标签
                        allPtag =infotag.find_all("p")

                        for Ptag in allPtag:
                            if 'class' not in Ptag.attrs:

                                title = "".join(Ptag.a.stripped_strings)

                    if title=="":
                        title="no title to get"

                    print('--------开始下载---------: %s' % title)
                    print('--------下载链接---------: %s' % pdfurl)
                    pdfFilePath =Parent.makedir(self.journal, vol, str(num),str(self.suc),pdfRoot)
                    if pdfFilePath == 1:
                        self.suc += 1
                        continue
                    fig = Parent.getPdf(pdfurl, title, pdfFilePath,hdrs)
                    if fig == -1:
                        self.ero += 1
                        line = 'journal: %s, vol: %s, issue: %s: %s 下载失败' % (
                        "汉语教学方法与技术", vol, num, title.strip())
                        line = line + '\n'
                        Parent.Record(line,self.journal)
                    if fig == 1:
                        print('%s,pdf下载成功' % title)
                        self.suc += 1

                        line = 'journal: %s, vol: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                        self.journal, vol, num, self.cnt, self.suc, self.ero)
                        line = line + '\n'
                        Parent.Record(line,self.journal)

                Parent.Record("\n", self.journal)
                return True


# if __name__ == "__main__":
#
#     work =cltmt()
#     work.getpdf("1","3","./")



import http.client, mimetypes, urllib, json, time, requests


######################################################################

class YDMHttp(object):
    """
    云打码已废弃，（跑路）
    """

    def __init__(self, username='office', password='officeHelper$123', appid=1, appkey='22cc5376925e9387a23cf797cb9ba745'):
        self.username = username
        self.password = password
        self.appid = str(appid)
        self.appkey = appkey
        self.apiurl = 'http://api.yundama.com/api.php'

    def request(self, fields, files=[]):
        response = self.post_url(self.apiurl, fields, files)
        response = json.loads(response)
        return response

    def balance(self):
        data = {'method': 'balance', 'username': self.username, 'password': self.password, 'appid': self.appid,
                'appkey': self.appkey}
        response = self.request(data)
        if (response):
            if (response['ret'] and response['ret'] < 0):
                return response['ret']
            else:
                return response['balance']
        else:
            return -9001

    def login(self):
        data = {'method': 'login', 'username': self.username, 'password': self.password, 'appid': self.appid,
                'appkey': self.appkey}
        response = self.request(data)
        if (response):
            if (response['ret'] and response['ret'] < 0):
                return response['ret']
            else:
                return response['uid']
        else:
            return -9001

    def upload(self, filename, codetype, timeout):
        data = {'method': 'upload', 'username': self.username, 'password': self.password, 'appid': self.appid,
                'appkey': self.appkey, 'codetype': str(codetype), 'timeout': str(timeout)}
        file = {'file': filename}
        response = self.request(data, file)
        if (response):
            if (response['ret'] and response['ret'] < 0):
                return response['ret']
            else:
                return response['cid']
        else:
            return -9001

    def result(self, cid):
        data = {'method': 'result', 'username': self.username, 'password': self.password, 'appid': self.appid,
                'appkey': self.appkey, 'cid': str(cid)}
        response = self.request(data)
        return response and response['text'] or ''

    def decode(self, filename, codetype, timeout):
        cid = self.upload(filename, codetype, timeout)
        if (cid > 0):
            for i in range(0, timeout):
                result = self.result(cid)
                if (result != ''):
                    return cid, result
                else:
                    time.sleep(1)
            return -3003, ''
        else:
            return cid, ''

    def report(self, cid):
        data = {'method': 'report', 'username': self.username, 'password': self.password, 'appid': self.appid,
                'appkey': self.appkey, 'cid': str(cid), 'flag': '0'}
        response = self.request(data)
        if (response):
            return response['ret']
        else:
            return -9001

    def post_url(self, url, fields, files=[]):
        #  在传入二进制时，下面两行官方代码需注释掉
        # for key in files:
        #     files[key] = open(files[key], 'rb');
        res = requests.post(url, files=files, data=fields)
        return res.text


######################################################################

    def Img2Code(self, content, codetype='1004', timeout=5):
        """

        :param content: 图片文件
        :param codetype: 验证码类型,
        例：1004表示4位字母数字，不同类型收费不同。请准确填写，否则影响识别率。
            在此查询所有类型 http://www.yundama.com/price.html
        :param timeout: 超时时间，秒
        :return: 验证码
        """

        # 登陆云打码
        uid = self.login()
        print('uid: %s' % uid)

        # 查询余额
        balance = self.balance()
        print('balance: %s' % balance)
        if int(balance) < 100000:
            print('Warning: Need Money !!!!!!!!!!!!!!!!!!!!!!!!!')

        # 开始识别，图片路径，验证码类型ID，超时时间（秒），识别结果
        cid, result = self.decode(content, codetype, timeout)
        print('cid: %s, result: %s' % (cid, result))
        return result





# -*- coding: utf-8 -*-
# @Time    : 2019/7/14 12:19
# @Author  : suhong
# @FileName: springer.py
# @Software: PyCharm
import math
import sys
import time

import requests
import  parent
from urllib import parse
from bs4 import BeautifulSoup
from lxml import etree

data = {}
hdrs = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer" :"https://link.springer.com",

}
Parent = parent.Parent()
class springer(object):


    def __init__(self):
        self.url = 'https://link.springer.com'
        self.ero = 0
        self.suc = 0
        self.cnt = 0
        self.journal = 'springer'

    def getpdf(self,jid,vol, num,pdfRoot):

        url = 'https://link.springer.com/journal/{}/{}/{}'.format(jid,vol,num)
        # data['year_id'] = years
        # data['quarter_id'] = num
        # print(years,num)
        # print(data)

        if "suppl" in num:
            url ='https://link.springer.com/journal/{}/{}/{}/{}'.format(jid,vol,num.split("_")[0],num.split("_")[-1])
        print(url)
        try:
            r = requests.get(url, headers=hdrs,  timeout =60)

            time.sleep(5)
        except:
            print('---------------访问失败------------')
            return False

        bs = BeautifulSoup(r.text, 'lxml')

        if bs.find(class_='toc').find("h2").find("span"):

            self.cnt = int("".join((bs.find(class_='toc').find("h2").find("span").stripped_strings)).replace(" articles","").replace("(","").replace(")",""))
            print("共计获取pdf文章:%s"%self.cnt)

        divs = bs.find_all(class_="toc-item")
        pdfnum = 0
        for onediv in divs:
            pdfnum +=1
            pdfurl =""
            page =""
            title1=""
            title=""

            if onediv.find(class_="actions"):

                if onediv.find(class_="actions").find("a",id='toc-pdf-link'):

                    # 获取下载pdf连接
                    pdfurl = "".join(onediv.find(class_="actions").find("a",id='toc-pdf-link')["href"])

                # 获取页数
                if onediv.find(class_="page-range"):
                    page = "".join(onediv.find(class_="page-range").stripped_strings).replace("Pages","").strip()

                # 获取title
                if onediv.find("h3",class_="title"):

                    if onediv.find("h3",class_="title").find("a"):

                        title1 = "".join(onediv.find("h3",class_="title").find("a").stripped_strings).strip()
            if page=="":
                title =title1

            else:
                title=page

            # 计数命名pdf
            title=str(pdfnum)

            if pdfurl == "":
                print("未发现pdf存在")
                continue
            url = "https://link.springer.com" +pdfurl

            print('--------开始下载---------: %s' % title1)
            pdfFilePath =Parent.makedir(self.journal, vol, str(num),title,pdfRoot)
            if pdfFilePath == 1:
                self.suc += 1
                continue
            pdf_hdrs = {"Connection": "keep-alive",
                        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
                    "Referer": "https://link.springer.com", }
            fig = Parent.getPdf(url, title, pdfFilePath,pdf_hdrs)
            if fig == -1:
                self.ero += 1
                line = 'journal: %s, vol: %s, issue: %s: %s 下载失败' % (
                self.journal, vol, num, title.strip())
                line = line + '\n'
                Parent.Record(line,self.journal)
            if fig == 1:
                print('%s,pdf下载成功' % title)
                self.suc += 1

                line = 'journal: %s, vol: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                self.journal, vol, num, self.cnt, self.suc, self.ero)
                line = line + '\n'
                Parent.Record(line,self.journal)

        if  math.ceil(self.cnt  / 20) > 1 :
            # 进行翻页操作
            allnum= math.ceil(self.cnt  / 20)

            for i in range(2,allnum+1):
                url = 'https://link.springer.com/journal/{}/{}/{}/page/{}'.format(jid, vol, num,str(i))
                # data['year_id'] = years
                # data['quarter_id'] = num
                # print(years,num)
                # print(data)

                if "suppl" in num:
                    url = 'https://link.springer.com/journal/{}/{}/{}/{}/page/{}'.format(jid, vol, num.split("_")[0],
                                                                                 num.split("_")[-1],str(i))
                print(url)
                try:
                    r = requests.get(url, headers=hdrs, timeout=60)

                    time.sleep(5)
                except:
                    print('---------------访问失败------------')
                    return False

                bs = BeautifulSoup(r.text, 'lxml')

                # if bs.find(class_='toc').find("h2").find("span"):
                #     self.cnt = int(
                #         "".join((bs.find(class_='toc').find("h2").find("span").stripped_strings)).replace(" articles",
                #                                                                                           "").replace(
                #             "(", "").replace(")", ""))
                #     print("共计获取pdf文章:%s" % self.cnt)

                divs = bs.find_all(class_="toc-item")

                for onediv in divs:
                    pdfnum +=1
                    pdfurl = ""
                    page = ""
                    title1 = ""
                    title = ""

                    if onediv.find(class_="actions"):

                        if onediv.find(class_="actions").find("a", id='toc-pdf-link'):
                            # 获取下载pdf连接
                            pdfurl = "".join(onediv.find(class_="actions").find("a", id='toc-pdf-link')["href"])

                        # 获取页数
                        if onediv.find(class_="page-range"):
                            page = "".join(onediv.find(class_="page-range").stripped_strings).replace("Pages",
                                                                                                      "").strip()

                        # 获取title
                        if onediv.find("h3", class_="title"):

                            if onediv.find("h3", class_="title").find("a"):
                                title1 = "".join(onediv.find("h3", class_="title").find("a").stripped_strings).strip()
                    if page == "":
                        title = title1

                    else:
                        title = page

                    # 重命名
                    title = str(pdfnum)

                    if pdfurl == "":
                        print("未发现pdf存在")
                        continue
                    url = "https://link.springer.com" + pdfurl

                    print('--------开始下载---------: %s' % title1)
                    pdfFilePath = Parent.makedir(self.journal, vol, str(num), title, pdfRoot)
                    if pdfFilePath == 1:
                        self.suc += 1
                        continue
                    pdf_hdrs ={   "Connection":"keep-alive","User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36",
        "Referer" :"https://link.springer.com",}
                    fig = Parent.getPdf(url, title, pdfFilePath, pdf_hdrs)
                    if fig == -1:
                        self.ero += 1
                        line = 'journal: %s, vol: %s, issue: %s: %s 下载失败' % (
                            self.journal, vol, num, title.strip())
                        line = line + '\n'
                        Parent.Record(line, self.journal)
                    if fig == 1:
                        print('%s,pdf下载成功' % title)
                        self.suc += 1

                        line = 'journal: %s, vol: %s, issue: %s。共有文章 %d；下载PDF %d；失败 %d' % (
                            self.journal, vol, num, self.cnt, self.suc, self.ero)
                        line = line + '\n'
                        Parent.Record(line, self.journal)

        Parent.Record("\n", self.journal)
        return True


# if __name__ == "__main__":
#
#     work =springer()
#     work.getpdf("40820","10","3","F:\\")


import setuptools

"""
# 打包教程
https://packaging.python.org/tutorials/packaging-projects/


test.pypi
updatepypi
[pypi]
  username = __token__
  password = pypi-AgENdGVzdC5weXBpLm9yZwIkZDU5NzdkOWUtN2NmNy00MDhjLWI3ZmMtOWY1NmQxOTRiMTU0AAIleyJwZXJtaXNzaW9ucyI6ICJ1c2VyIiwgInZlcnNpb24iOiAxfQAABiCmmvSirLVoekGxZAQ4e5EMSnF7vrkdqYrOdEC1PXaaPg

python3 setup.py sdist bdist_wheel
python3 -m twine upload --repository-url https://test.pypi.org/legacy/ dist/*

pypi
re_common

[pypi]
  username = __token__
  password = pypi-AgEIcHlwaS5vcmcCJDdlYTBjNzZjLTU2NDItNGExYy04NzY4LWIxM2IyMzgzZjFiYgACJXsicGVybWlzc2lvbnMiOiAidXNlciIsICJ2ZXJzaW9uIjogMX0AAAYgPjmPag7MzYc7m6hG5x5-RGYtOolOXPWtTb88iMdB3xE
  
python setup.py sdist bdist_wheel
python -m twine upload dist/*

"""
long_description = """
    这是一个基础类，依赖很多的第三方包，是一个用得到的第三方库的封装，可以在此基础上迅速构建项目
"""
setuptools.setup(
    name="re_common",

    version="0.1.9",
    author="vic",
    author_email="xujiang5@163.com",
    description="a library about all python projects",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/xujiangios/re-common",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 2 - Pre-Alpha",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



# -*- coding: utf-8 -*-
# @Time    : 2020/9/16 13:18
# @Author  : suhong
# @File    : mcss.py
# @Software: PyCharm
from parsel import Selector
class MParsel(object):
    def __init__(self,logger=None):
        if logger is None:
            from re_common.baselibrary import MLogger
            logger = MLogger().streamlogger
        self.logger = logger



    def css_parsel_html(self,html="",css_selector={}):
        if html != "" and css_selector:
            sel = Selector(html)
            dict_ = dict()
            for key,value in css_selector.items():
                dict_[key] = sel.css(value).getall()
            return True,dict_
        else:
            return False,""

    def xpath_parsel_html(self,html="",xpath_selector={}):
        if html != "" and xpath_selector:
            sel = Selector(html)
            dict_ = dict()
            for key,value in xpath_selector.items():
                dict_[key] = sel.xpath(value).getall()
            return True,dict_
        else:
            return False,""



    def asd(self):
        pass




"""
重命名目录下的文件
"""
from re_common.baselibrary.utils.basedir import BaseDir
from re_common.baselibrary.utils.basefile import BaseFile


def get_next_suffix(num):
    num = num + 1
    return "_" + str(num).zfill(4)


def rename_db3(dirpath, rename, start=0):
    """
    重命名db3　文件　以后缀_001 或者　_000 开始
    :param rename:
    :param start: 1 代表_001　0代表_000
    :return:
    """
    """
    
    :param dirpath: 
    :param rename: 
    :param start: 
    :return: 
    """

    for file in BaseDir.get_dir_all_files(dirpath):
        if file.endswith(".db3"):
            BaseDir.get_upper_dir(file, -1)
            renamepath = BaseFile.get_new_path(dirpath, rename + get_next_suffix(start) + ".db3")
            BaseFile.rename_file(file, renamepath)
            start = start + 1


rename_db3(r"\\192.168.31.65\d$\zt_data_db3\zt_normal_grx\zt_cnki_qk_20200323", "zt_cnki_qk_20200323")
rename_db3(r"\\192.168.31.65\d$\zt_data_db3\zt_normal_grx\zt_wf_qk_20200323", "zt_wf_qk_20200323")



import gzip
import json
import sys

from re_common.baselibrary.utils.basedir import BaseDir
from re_common.baselibrary.utils.basefile import BaseFile

ref_outPathFile = r"F:\fun3\ref\cnkiref.big_json.gz"
f_ref = gzip.open(ref_outPathFile, "wb")
if BaseFile.get_file_size(ref_outPathFile) >= 100 * 1024 * 1024:
    f_ref.close()
    ref_outPathFile = BaseFile.change_file(ref_outPathFile, size=100 * 1024 * 1024)
    ref_outPathFile = ref_outPathFile.replace(".big_json", '.big_json.gz')
    f_ref = gzip.open(ref_outPathFile, "wb")
    print("new dst_path: %s" % ref_outPathFile)
for file in BaseDir.get_dir_all_files(r"F:\fun2\ref"):
    print(file)
    with gzip.open(file, 'r') as f:
        for lineb in f:
            line = lineb.decode()
            linedicts = json.loads(line)
            print(linedicts)
            if "stat" in linedicts:
                for key in linedicts:
                    if key == "stat":
                        continue
                    else:
                        print(key)
                        tempdicts = linedicts[key]
                        print(tempdicts)
                        line_ref = json.dumps(tempdicts, ensure_ascii=False) + "\n"
                        line_refs = line_ref.encode()
                        f_ref.write(line_refs)
            else:
                f_ref.write(lineb)
            if BaseFile.get_file_size(ref_outPathFile) >= 100 * 1024 * 1024:
                f_ref.close()
                ref_outPathFile = BaseFile.change_file(ref_outPathFile, size=100 * 1024 * 1024)
                ref_outPathFile = ref_outPathFile.replace(".big_json", '.big_json.gz')
                f_ref = gzip.open(ref_outPathFile, "wb")
                print("new dst_path: %s" % ref_outPathFile)


# -*- coding: utf-8 -*-
# @Time    : 2020/6/10 10:08
# @Author  : suhong
# @File    : wangfang_pdf_down.py
# @Software: PyCharm

# # 同项目调用基础包
# import os
# import sys
#
# filepath = os.path.abspath(__file__)
# pathlist = filepath.split(os.sep)
# pathlist = pathlist[:-5]
# TopPath = os.sep.join(pathlist)
# sys.path.insert(0, TopPath)
# print(TopPath)

import json
import os
from parsel import Selector
from urllib import parse
import requests
import time

import toml
from re_common.baselibrary.utils.basedir import BaseDir




from bs4 import BeautifulSoup


class Down(object):
    def __init__(self):
        self.sn = None
        self.index_url = "http://www.wanfangdata.com.cn/sns/third-web/per/perio/articleList"
        self.perioname = None
        self.publishYear = None
        self.issueNum = None
        self.proxies = None
        self.perioId = None
        self.pdf_path = None
        self.UserAgent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:60.0) Gecko/20100101 Firefox/60.0'


    def read_toml(self):
        cfgFile = r"./config.toml"
        config = toml.load(cfgFile)
        self.pdf_path = config['pdf_path']
        BaseDir.create_dir(self.pdf_path)
        proxy = config['proxy']
        self.proxies = {
            "http": proxy,
            "https": proxy,
        }
        for info in config['info']['NameList']:
            self.perioname, self.publishYear, self.issueNum = info[0], info[1], info[2]
            print("开始下载{}-{}年-{}期".format(self.perioname, self.publishYear, self.issueNum))
            self.get_id()


    def get_perioid(self):
        url = "http://www.wanfangdata.com.cn/search/searchList.do?searchType=perioInfo&showType=detail&pageSize=20&searchWord={}&isTriggerTag=".format(
            parse.quote(self.perioname))
        r = requests.get(url)
        html = Selector(r.text)
        id_ = html.xpath("//div[@class='title title_h']//a[@class='perInfo_block_title']/@href").extract_first("")
        self.perioId = id_.replace("/perio/detail.do?perio_id=", "")

    def get_id(self):
        self.get_perioid()
        self.Tmp_pdf = r'{}/{}/{}/{}'.format(self.pdf_path,self.perioname, self.publishYear, self.issueNum)
        if not os.path.exists(self.Tmp_pdf):
            os.makedirs(self.Tmp_pdf)
        data = {
            "page": 1,
            "pageSize": 60,
            "perioId": self.perioId,
            "title": "",
            "publishYear": self.publishYear,
            "issueNum": self.issueNum,
            "otherYear": ""
        }
        r = requests.post(self.index_url, data=data)
        json_data = json.loads(r.text)
        all_num = json_data['totalRow']
        print("pdf数量：{}".format(all_num))
        max_page = int(all_num // 60) + 1
        for page in range(1, max_page + 1):
            data = {
                "page": page,
                "pageSize": 60,
                "perioId": self.perioId,
                "title": "",
                "publishYear": self.publishYear,
                "issueNum": self.issueNum,
                "otherYear": ""
            }
            r = requests.post(self.index_url, data=data)
            json_data = json.loads(r.text)
            for info in json_data['pageRow']:
                self.sn = requests.Session()
                self.sn.headers['User-Agent'] = self.UserAgent
                rtn = self.down_one(info)
                if rtn[0] != 1:
                    return -1 * rtn[0]
                pdfUrl = rtn[1][0]
                title = rtn[1][1]
                title = BaseDir.replace_dir_special_string(title)
                pdf_path = r"{}/{}.pdf".format(self.Tmp_pdf, title)
                if os.path.exists(pdf_path):
                    print("{}存在".format(pdf_path))
                    continue
                try:
                    r = self.sn.get(url=pdfUrl, proxies=self.proxies)
                except:
                    return 0

                self.sava_pdf(r, title)
                time.sleep(2)

    def sava_pdf(self, res, title):
        pdf_path = r"{}/{}.pdf".format(self.Tmp_pdf, title)
        try:
            with open(pdf_path, mode='wb') as f:
                f.write(res.content)
                print("缓存PDF至本地成功:{}".format(title))
            return 1
        except:
            print("缓存PDF至本地失败:{}".format(title))
            return 0

    def down_one(self, info):
        rawid = info['article_id']
        doctype = "perio"
        self.sn.headers['Referer'] = r'http://www.wanfangdata.com.cn/pay/downloadliterature.do?_type=%s&id=%s' % (
            doctype, rawid)

        detailUrl = r'http://www.wanfangdata.com.cn/details/detail.do?_type=%s&id=%s' % (doctype, rawid)
        try:
            r = self.sn.get(url=detailUrl, proxies=self.proxies, timeout=30)
        except:
            return 0, 0
        if r.status_code != 200:
            return 0, 0

        html = r.content.decode('utf-8')
        soup = BeautifulSoup(html, 'html.parser')
        aTag = soup.find('a', id='ddownb')
        if not aTag:
            print('{}所查找的文献详情页无下载链接'.format(rawid))
            return -2, 0
        onclick = aTag.get('onclick').replace('\r', ' ').replace('\n', ' ')
        idx1 = onclick.find('(')
        idx2 = onclick.rfind(')')
        rsEval = eval(onclick[idx1 + 1:idx2])

        if len(rsEval) == 7:
            page_cnt, resourceId, language, source, resourceTitle, isoa, resourceType = eval(onclick[idx1 + 1:idx2])
            first = ""
            searchUrl = r"http://www.wanfangdata.com.cn/search/downLoad.do?page_cnt={}&language={}&resourceType={}&source={}&resourceId={}&resourceTitle={}&isoa={}&type={}&first={}"
            searchUrl = searchUrl.format(page_cnt, language, resourceType, source, resourceId, isoa, resourceTitle,
                                         resourceType, isoa, first)
        elif len(rsEval) == 8:
            page_cnt, resourceId, language, source, resourceTitle, isoa, resourceType, first = rsEval
            searchUrl = r'http://www.wanfangdata.com.cn/search/downLoad.do?page_cnt=%s&language=%s&resourceType=%s&source=%s&resourceId=%s&resourceTitle=%s&isoa=%s'
            searchUrl = searchUrl % (page_cnt, language, resourceType, source, resourceId, resourceTitle, isoa)
        else:
            print('{}所查找的文献格式存在多样性'.format(rawid))
            return -3, 0
        self.sn.headers['Referer'] = detailUrl

        try:
            r = self.sn.get(url=searchUrl, proxies=self.proxies, timeout=30)
        except:
            return 0
        if r.status_code != 200:
            return 0
        paramDict = parse.parse_qs(parse.urlparse(r.url).query)

        if 'id' not in paramDict:
            print('{}所查找的文献详情页下载链接有误'.format(rawid))
            return -4, 0
        title = ''
        if 'title' in paramDict:  # title可能不存在，比如：rdflpl201604001
            title = paramDict['title'][0]
        pdfUrl = r'http://common.wanfangdata.com.cn/download/download.do?type=%s&resourceId=%s&resourceTitle=%s&transaction=%s'
        pdfUrl = pdfUrl % (parse.quote(doctype),
                           parse.quote(paramDict['id'][0]),
                           parse.quote(parse.quote(title)),
                           parse.quote(paramDict['transaction'][0]))
        return 1, (pdfUrl, title)


if __name__ == '__main__':

    d = Down()
    d.read_toml()



# 这个库会加载所有的模块，也可以知道本基础库使用了哪些模块
from re_common.baselibrary.utils.baserequest import BaseRequest

from .mysqlfacade import MysqlUtiles

from re_common.baselibrary import IniConfig
from re_common.baselibrary.readconfig.toml_config import TomlConfig
from .loggerfacade import MLogger

__all__ = ['get_streamlogger', 'get_filelogger', 'get_timerotatingfilelogger', 'BaseRequest']

"""
提供logger的使用外观  外观模式
"""


def get_streamlogger():
    """
    提供一个输出流的logger
    :return:
    """
    return MLogger().streamlogger


def get_filelogger(filedir):
    """
    文件流的logger
    :param filedir:
    :return:
    """
    return MLogger(filedir).filelogger


def get_timerotatingfilelogger(filedir, fileter=None):
    return MLogger(filedir, fileter).timerotatingfilelogger
